@@ -1,8 +1,11 @@
 import * as React from 'react';
 import * as _ from 'lodash';
 import * as classNames from 'classnames';
-import { DashboardCardHelp } from '@console/internal/components/dashboard/dashboard-card';
-import { RequestSizeInput, withHandlePromise } from '@console/internal/components/utils/index';
+import {
+  FieldLevelHelp,
+  RequestSizeInput,
+  withHandlePromise,
+} from '@console/internal/components/utils/index';
 import {
   createModalLauncher,
   ModalBody,
@@ -17,9 +20,9 @@ import { OCSStorageClassDropdown } from '../storage-class-dropdown';
 export const AddCapacityModal = withHandlePromise((props: AddCapacityModalProps) => {
   const { ocsConfig, close, cancel } = props;
   const dropdownUnits = {
-    Ti: 'Ti',
+    TiB: 'TiB',
   };
-  const requestSizeUnit = dropdownUnits.Ti;
+  const requestSizeUnit = dropdownUnits.TiB;
   const [buttonDisabled, setButton] = React.useState(false);
   const [requestSizeValue, setRequestSizeValue] = React.useState('2');
   const [storageClass, setStorageClass] = React.useState('');
@@ -75,7 +78,7 @@ export const AddCapacityModal = withHandlePromise((props: AddCapacityModalProps)
           <div className="add-capacity-modal__input form-group">
             <label className="control-label" htmlFor="request-size-input">
               Capacity
-              <DashboardCardHelp>{labelTooltip}</DashboardCardHelp>
+              <FieldLevelHelp>{labelTooltip}</FieldLevelHelp>
               <span className="text-secondary add-capacity-modal__span">
                 <span>
                   Provisioned:
@@ -105,7 +108,7 @@ export const AddCapacityModal = withHandlePromise((props: AddCapacityModalProps)
           </div>
           <label className="control-label">
             Storage Class
-            <DashboardCardHelp>{storageClassTooltip}</DashboardCardHelp>
+            <FieldLevelHelp>{storageClassTooltip}</FieldLevelHelp>
           </label>
           <OCSStorageClassDropdown
             onChange={handleStorageClass}
