@@ -3,13 +3,20 @@ import { Alert } from '@patternfly/react-core';
 import { K8sResourceKind, K8sKind } from '@console/internal/module/k8s';
 import { ListPage } from '@console/internal/components/factory';
 import { NodeModel } from '@console/internal/models';
-import { ClusterServiceVersionKind } from '@console/internal/components/operator-lifecycle-manager/index';
+import { ClusterServiceVersionKind } from '@console/operator-lifecycle-manager/src/types';
 import { NodeList } from './node-list';
 
 import './ocs-install.scss';
 
-export const CreateOCSServiceForm: React.FC<CreateOCSServiceFormProps> = (props) => {
+export const CreateOCSServiceForm: React.FC<CreateOCSServiceFormProps> = ({
+  namespace,
+  clusterServiceVersion,
+}) => {
   const title = 'Create New OCS Service';
+  const ListComponent = React.useCallback(
+    (nodeProps) => <NodeList {...nodeProps} ocsProps={{ namespace, clusterServiceVersion }} />,
+    [namespace, clusterServiceVersion],
+  );
 
   return (
     <div className="co-m-pane__body co-m-pane__form">
@@ -37,11 +44,7 @@ export const CreateOCSServiceForm: React.FC<CreateOCSServiceFormProps> = (props)
           <p className="co-legend co-required ceph-ocs-desc__legend">
             Select at least 3 nodes in different failure domains you wish to use.
           </p>
-          <ListPage
-            kind={NodeModel.kind}
-            showTitle={false}
-            ListComponent={(nodeProps) => <NodeList {...nodeProps} ocsProps={props} />}
-          />
+          <ListPage kind={NodeModel.kind} showTitle={false} ListComponent={ListComponent} />
         </div>
       </form>
     </div>
