@@ -9,9 +9,15 @@ import {
   TableVariant,
   TableGridBreakpoint,
 } from '@patternfly/react-table';
-import { getInfrastructurePlatform } from '@console/shared';
+import {
+  getInfrastructurePlatform,
+  getName,
+  getNodeRoles,
+  getNodeCPUCapacity,
+  getNodeAllocatableMemory,
+} from '@console/shared';
+import { Alert, ActionGroup, Button } from '@patternfly/react-core';
 import { tableFilters } from '@console/internal/components/factory/table-filters';
-import { ActionGroup, Button } from '@patternfly/react-core';
 import { ButtonBar } from '@console/internal/components/utils/button-bar';
 import { history } from '@console/internal/components/utils/router';
 import {
@@ -21,7 +27,6 @@ import {
   ResourceLink,
 } from '@console/internal/components/utils/index';
 import {
-  getNodeRoles,
   k8sCreate,
   k8sPatch,
   k8sGet,
@@ -30,16 +35,21 @@ import {
   NodeKind,
   referenceForModel,
   StorageClassResourceKind,
+  Taint,
 } from '@console/internal/module/k8s';
 import { NodeModel, InfrastructureModel, StorageClassModel } from '@console/internal/models';
+import { isDefaultClass } from '@console/internal/components/storage-class';
 import { OCSServiceModel } from '../../models';
-import { infraProvisionerMap, minSelectedNode, ocsRequestData } from '../../constants/ocs-install';
-
+import {
+  infraProvisionerMap,
+  minSelectedNode,
+  ocsRequestData,
+  ocsTaint,
+} from '../../constants/ocs-install';
 import './ocs-install.scss';
+import { hasLabel } from '../../../../console-shared/src/selectors/common';
 
 const ocsLabel = 'cluster.ocs.openshift.io/openshift-storage';
-const nodeLabel = 'cluster.ocs.openshift.io~1openshift-storage';
-const defaultSAnotations = { 'storageclass.kubernetes.io/is-default-class': 'true' };
 
 const getConvertedUnits = (value: string) => {
   return humanizeBinaryBytes(convertToBaseValue(value)).string || '-';
@@ -79,36 +89,52 @@ const getColumns = () => {
   ];
 };
 
+const hasTaints = (node: NodeKind) => {
+  return !_.isEmpty(node.spec.taints);
+};
+
+const hasOCSTaint = (node: NodeKind) => {
+  const taints: Taint[] = node.spec.taints || [];
+  return taints.some((taint: Taint) => _.isEqual(taint, ocsTaint));
+};
+
 // return an empty array when there is no data
 const getRows = (nodes: NodeKind[]) => {
-  return nodes.map((node) => {
-    const roles = getNodeRoles(node).sort();
-    const obj = {
-      cells: [],
-      selected: false,
-      id: node.metadata.name,
-      metadata: _.clone(node.metadata),
-      spec: _.clone(node.spec),
-    };
-    obj.cells = [
-      {
-        title: <ResourceLink kind="Node" name={node.metadata.name} title={node.metadata.uid} />,
-      },
-      {
-        title: roles.join(', ') || '-',
-      },
-      {
-        title: _.get(node.metadata.labels, 'failure-domain.beta.kubernetes.io/zone') || '-',
-      },
-      {
-        title: `${humanizeCpuCores(_.get(node.status, 'capacity.cpu')).string || '-'}`,
-      },
-      {
-        title: `${getConvertedUnits(_.get(node.status, 'allocatable.memory'))}`,
-      },
-    ];
-    return obj;
-  });
+  return nodes
+    .filter((node) => hasOCSTaint(node) || !hasTaints(node))
+    .map((node) => {
+      const roles = getNodeRoles(node).sort();
+      const cpuCapacity: string = getNodeCPUCapacity(node);
+      const allocatableMemory: string = getNodeAllocatableMemory(node);
+      const cells = [
+        {
+          title: <ResourceLink kind="Node" name={node.metadata.name} title={node.metadata.uid} />,
+        },
+        {
+          title: roles.join(', ') || '-',
+        },
+        {
+          title: _.get(node.metadata.labels, 'failure-domain.beta.kubernetes.io/zone') || '-',
+        },
+        {
+          title: `${humanizeCpuCores(cpuCapacity).string || '-'}`,
+        },
+        {
+          title: `${getConvertedUnits(allocatableMemory)}`,
+        },
+      ];
+      const obj = {
+        cells,
+        selected: false,
+        id: node.metadata.name,
+        metadata: _.clone(node.metadata),
+        spec: _.clone(node.spec),
+        cpuCapacity,
+        allocatableMemory,
+      };
+
+      return obj;
+    });
 };
 
 const getFilteredRows = (filters: {}, objects: any[]) => {
@@ -139,41 +165,79 @@ const stateToProps = (obj, { data = [], filters = {}, staticFilters = [{}] }) =>
   const newData = getFilteredRows(allFilters, data);
   return {
     data: newData,
+    unfilteredData: data,
+    isFiltered: !!_.get(filters, 'name'),
   };
 };
-
-const CustomNodeTable: React.FC<CustomNodeTableProps> = ({ data, loaded, ocsProps }) => {
+const CustomNodeTable: React.FC<CustomNodeTableProps> = ({
+  data,
+  unfilteredData,
+  isFiltered,
+  loaded,
+  ocsProps,
+}) => {
   const columns = getColumns();
   const [nodes, setNodes] = React.useState([]);
+  const [unfilteredNodes, setUnfilteredNodes] = React.useState([]);
   const [error, setError] = React.useState('');
   const [inProgress, setProgress] = React.useState(false);
   const [selectedNodesCnt, setSelectedNodesCnt] = React.useState(0);
+  const [nodesWarningMsg, setNodesWarningMsg] = React.useState('');
 
   let storageClass = '';
 
-  React.useEffect(() => {
-    const selectedNode = _.filter(nodes, 'selected').length;
-    setSelectedNodesCnt(selectedNode);
-  }, [nodes]);
+  // pre-selection of nodes
+  if (loaded && !unfilteredNodes.length) {
+    const formattedNodes: formattedNodeType[] = getRows(unfilteredData);
+    const preSelectedNodes = getPreSelectedNodes(formattedNodes);
+    setUnfilteredNodes(preSelectedNodes);
+    setNodes(preSelectedNodes);
+  }
 
-  React.useEffect(() => {
-    let formattedNodes = getRows(data);
+  const hasMinimumCPU = (node: formattedNodeType): boolean => {
+    return convertToBaseValue(node.cpuCapacity) >= 16;
+  };
 
-    // pre-selection of nodes
-    if (loaded && !nodes.length) {
-      formattedNodes = getPreSelectedNodes(formattedNodes);
-      setNodes(formattedNodes);
+  const hasMinimumMemory = (node: formattedNodeType): boolean => {
+    return convertToBaseValue(node.allocatableMemory) >= convertToBaseValue('64 Gi');
+  };
+
+  const validateNodes = React.useCallback((selectedNodes: formattedNodeType[]): void => {
+    let invalidNodesCount = 0;
+    let nodeName = '';
+    selectedNodes.forEach((node: formattedNodeType) => {
+      if (!hasMinimumCPU(node) || !hasMinimumMemory(node)) {
+        invalidNodesCount += 1;
+        nodeName = node.id;
+      }
+    });
+
+    if (invalidNodesCount > 0) {
+      const msg =
+        invalidNodesCount > 1
+          ? `${invalidNodesCount} of the selected nodes do not meet minimum requirements of 16 cores and 64 GiB Memory`
+          : `Node ${nodeName} does not meet minimum requirements of 16 cores and 64 GiB memory.`;
+      setNodesWarningMsg(msg);
+    } else {
+      setNodesWarningMsg('');
     }
-    // for getting nodes
-    else if (formattedNodes.length) {
-      const nodesByID = _.keyBy(nodes, 'id');
-      _.each(formattedNodes, (n) => {
-        n.selected = _.get(nodesByID, [n.id, 'selected']);
+  }, []);
+
+  React.useEffect(() => {
+    const selectedNodes = _.filter(unfilteredNodes, 'selected');
+    setSelectedNodesCnt(selectedNodes.length);
+    validateNodes(selectedNodes);
+  }, [nodes, unfilteredNodes, validateNodes]);
+
+  React.useEffect(() => {
+    if (isFiltered || nodes.length !== data.length) {
+      const unfilteredNodesByID = _.keyBy(unfilteredNodes, 'metadata.name');
+      const filterData = _.each(getRows(data), (n) => {
+        n.selected = _.get(unfilteredNodesByID, [n.id, 'selected'], false);
       });
-      setNodes(formattedNodes);
+      setNodes(filterData);
     }
-    // eslint-disable-next-line react-hooks/exhaustive-deps
-  }, [JSON.stringify(data), loaded]);
+  }, [data, isFiltered, nodes.length, unfilteredNodes]);
 
   const onSelect = (
     event: React.MouseEvent<HTMLButtonElement>,
@@ -192,19 +256,32 @@ const CustomNodeTable: React.FC<CustomNodeTableProps> = ({ data, loaded, ocsProp
       formattedNodes[index].selected = isSelected;
     }
     setNodes(formattedNodes);
+    const nodesByID = _.keyBy(nodes, 'id');
+    const setSelectedUnfilteredNodes = _.each(unfilteredNodes, (n) => {
+      if (_.get(nodesByID, [n.id, 'id']) === n.metadata.name) {
+        n.selected = _.get(nodesByID, [getName(n), 'selected'], false);
+      }
+    });
+    setUnfilteredNodes(setSelectedUnfilteredNodes);
   };
 
   const makeLabelNodesRequest = (selectedNodes: NodeKind[]): Promise<NodeKind>[] => {
-    return selectedNodes.map((node: NodeKind) => {
-      const patch = [
-        {
-          op: 'add',
-          path: `/metadata/labels/${nodeLabel}`,
-          value: '',
-        },
-      ];
-      return k8sPatch(NodeModel, node, patch);
-    });
+    const patch = [
+      {
+        op: 'add',
+        path: '/metadata/labels/cluster.ocs.openshift.io~1openshift-storage',
+        value: '',
+      },
+    ];
+    return _.reduce(
+      selectedNodes,
+      (accumulator, node) => {
+        return hasLabel(node, ocsLabel)
+          ? accumulator
+          : [...accumulator, k8sPatch(NodeModel, node, patch)];
+      },
+      [],
+    );
   };
 
   // tainting the selected nodes
@@ -232,17 +309,17 @@ const CustomNodeTable: React.FC<CustomNodeTableProps> = ({ data, loaded, ocsProp
 
   const makeOCSRequest = () => {
     const selectedData: NodeKind[] = _.filter(nodes, 'selected');
-    const promises = [];
-
-    promises.push(...makeLabelNodesRequest(selectedData));
+    const promises = makeLabelNodesRequest(selectedData);
     // intentionally keeping the taint logic as its required in 4.3 and will be handled with checkbox selection
     // promises.push(...makeTaintNodesRequest(selectedData));
 
     const ocsObj = _.cloneDeep(ocsRequestData);
     ocsObj.spec.storageDeviceSets[0].dataPVCTemplate.spec.storageClassName = storageClass;
-    promises.push(k8sCreate(OCSServiceModel, ocsObj));
 
     Promise.all(promises)
+      .then(() => {
+        return k8sCreate(OCSServiceModel, ocsObj);
+      })
       .then(() => {
         history.push(
           `/k8s/ns/${ocsProps.namespace}/clusterserviceversions/${
@@ -274,7 +351,7 @@ const CustomNodeTable: React.FC<CustomNodeTableProps> = ({ data, loaded, ocsProp
         const scList = _.filter(storageClasses, (sc) => sc.provisioner === provisioner);
         // take the default storageclass
         _.forEach(scList, (sc) => {
-          if (sc.metadata && _.isEqual(sc.metadata.annotations, defaultSAnotations)) {
+          if (isDefaultClass(sc)) {
             storageClass = sc.metadata.name;
           }
         });
@@ -288,8 +365,9 @@ const CustomNodeTable: React.FC<CustomNodeTableProps> = ({ data, loaded, ocsProp
 
   return (
     <>
-      <div className="node-list__max-height">
+      <div className="ceph-node-list__max-height">
         <Table
+          aria-label="node list table"
           onSelect={onSelect}
           cells={columns}
           rows={nodes}
@@ -303,6 +381,14 @@ const CustomNodeTable: React.FC<CustomNodeTableProps> = ({ data, loaded, ocsProp
       <p className="control-label help-block" id="nodes-selected">
         {selectedNodesCnt} node(s) selected
       </p>
+      {nodesWarningMsg.length > 0 && (
+        <Alert
+          className="co-alert ceph-ocs-install__alert"
+          variant="warning"
+          title={nodesWarningMsg}
+          isInline
+        />
+      )}
       <ButtonBar errorMessage={error} inProgress={inProgress}>
         <ActionGroup className="pf-c-form">
           <Button
@@ -326,8 +412,10 @@ export const NodeList = connect<{}, CustomNodeTableProps>(stateToProps)(CustomNo
 
 type CustomNodeTableProps = {
   data: NodeKind[];
+  unfilteredData: UnfilteredDataType[];
   loaded: boolean;
   ocsProps: ocsPropsType;
+  isFiltered: boolean;
 };
 
 type ocsPropsType = {
@@ -335,10 +423,16 @@ type ocsPropsType = {
   clusterServiceVersion: K8sResourceKind;
 };
 
+type UnfilteredDataType = NodeKind & {
+  selected: boolean;
+};
+
 type formattedNodeType = {
   cells: any[];
   selected: boolean;
   id: string;
   metadata: {};
   spec: {};
+  cpuCapacity: string;
+  allocatableMemory: string;
 };
