@@ -1,4 +1,5 @@
 export * from './extension';
+export * from './types';
 
 // TODO(vojtech): internal code needed by plugin SDK should be moved to console-shared package
 
@@ -13,4 +14,5 @@ export * from './perspectives';
 export * from './yaml-templates';
 export * from './global-configs';
 export * from './clusterserviceversions';
-export * from './plugins/ceph-storage-plugin';
+export * from './dev-catalog';
+export * from './reducers';
