@@ -2,6 +2,7 @@ import * as React from 'react';
 import { RouteComponentProps } from 'react-router-dom';
 import { Helmet } from 'react-helmet';
 import { PageHeading, Firehose } from '@console/internal/components/utils';
+import { ImageStreamModel } from '@console/internal/models';
 import NamespacedPage, { NamespacedPageVariants } from '../NamespacedPage';
 import DeployImage from './DeployImage';
 
@@ -16,7 +17,16 @@ const DeployImagePage: React.FunctionComponent<DeployImagePageProps> = ({ match
       </Helmet>
       <PageHeading title="Deploy Image" />
       <div className="co-m-pane__body">
-        <Firehose resources={[{ kind: 'Project', prop: 'projects', isList: true }]}>
+        <Firehose
+          resources={[
+            { kind: 'Project', prop: 'projects', isList: true },
+            {
+              kind: ImageStreamModel.kind,
+              prop: 'imageStreams',
+              isList: true,
+            },
+          ]}
+        >
           <DeployImage namespace={namespace} />
         </Firehose>
       </div>
