@@ -1,28 +1,31 @@
 /* eslint-disable react/no-multi-comp */
 import * as React from 'react';
+import * as classNames from 'classnames';
 import * as d3 from 'd3';
 import * as ReactDOM from 'react-dom';
 import * as _ from 'lodash';
 import { confirmModal, errorModal } from '@console/internal/components/modals';
-import SvgDefsProvider from '../svg/SvgDefsProvider';
+import { SVGDefsProvider } from '@console/topology';
 import {
-  ViewNode,
-  ViewEdge,
-  NodeProvider,
+  ContextMenuProvider,
+  DragConnectionProps,
+  Edge,
+  EdgeProps,
   EdgeProvider,
+  GraphElementType,
+  GraphModel,
+  GroupElementInterface,
+  GroupProps,
+  GroupProvider,
   NodeProps,
+  NodeProvider,
   TopologyDataMap,
   TopologyDataObject,
-  GraphModel,
-  Edge,
+  ViewEdge,
   ViewGroup,
-  GroupProvider,
-  GroupProps,
-  GroupElementInterface,
-  DragConnectionProps,
-  EdgeProps,
+  ViewNode,
 } from './topology-types';
-import { DraggingCreateConnector, dragConnectorEndPoint } from './shapes/DraggingCreateConnector';
+import { dragConnectorEndPoint, DraggingCreateConnector } from './shapes/DraggingCreateConnector';
 import { DraggingMoveConnector } from './shapes/DraggingMoveConnector';
 
 const ZOOM_EXTENT: [number, number] = [0.25, 4];
@@ -71,16 +74,18 @@ export interface D3ForceDirectedRendererProps {
   nodeProvider: NodeProvider;
   edgeProvider: EdgeProvider;
   groupProvider: GroupProvider;
+  contextMenu: ContextMenuProvider;
   nodeSize: number;
   selected?: string;
-  onSelect?(string): void;
+  selectedType?: string;
+  onSelect?(type: GraphElementType, id: string): void;
   onUpdateNodeGroup?(nodeId: string, targetGroup: string): Promise<any>;
   onCreateConnection?(
     sourceNodeId: string,
     targetNodeId: string,
     replaceTargetNodeId?: string,
   ): Promise<any>;
-  onRemoveConnection?(sourceNodeId: string, targetNodeId: string): void;
+  onRemoveConnection?(sourceNodeId: string, targetNodeId: string, edgeType: string): void;
 }
 
 function getEdgeId(d: Edge): string {
@@ -256,7 +261,7 @@ export default class D3ForceDirectedRenderer extends React.Component<
     if (this.ignoreNextSizeChange && sizeChanged) {
       this.ignoreNextSizeChange = false;
       if (this.props.selected) {
-        this.makeNodeVisible(this.props.selected);
+        this.makeSelectionVisible();
       }
     }
 
@@ -306,22 +311,47 @@ export default class D3ForceDirectedRenderer extends React.Component<
     this.setState({ zoomTransform: d3.event.transform });
   };
 
-  private makeNodeVisible = (nodeId: string) => {
+  private makeBoxVisible = (boundingBox: {
+    left: number;
+    right: number;
+    top: number;
+    bottom: number;
+  }) => {
     const { width, height } = this.props;
-    const { nodesById, zoomTransform = { x: 0, y: 0, k: 1 } } = this.state;
-    const node: ViewNode = nodesById[nodeId];
-    let moveToNode = false;
+    const { zoomTransform = { x: 0, y: 0, k: 1 } } = this.state;
+    let move = false;
     const panOffset = 20;
 
-    if (!node) {
-      return;
-    }
-
     const center = {
       x: (width / 2 - zoomTransform.x) / zoomTransform.k,
       y: (height / 2 - zoomTransform.y) / zoomTransform.k,
     };
 
+    if (boundingBox.right < 0) {
+      center.x += (boundingBox.left - panOffset) / zoomTransform.k;
+      move = true;
+    }
+    if (boundingBox.left > width) {
+      center.x += (boundingBox.right - width + panOffset) / zoomTransform.k;
+      move = true;
+    }
+    if (boundingBox.bottom < 0) {
+      center.y += (boundingBox.top - panOffset) / zoomTransform.k;
+      move = true;
+    }
+    if (boundingBox.top > height) {
+      center.y += (boundingBox.bottom - height + panOffset) / zoomTransform.k;
+      move = true;
+    }
+
+    if (move) {
+      this.zoom.translateTo(this.$svg, center.x, center.y);
+    }
+  };
+
+  private getNodeBoundingBox = (node: ViewNode) => {
+    const { zoomTransform = { x: 0, y: 0, k: 1 } } = this.state;
+
     const nodeMin = {
       x: zoomTransform.x + (node.x - node.size / 2) * zoomTransform.k,
       y: zoomTransform.y + (node.y - node.size / 2) * zoomTransform.k,
@@ -331,26 +361,60 @@ export default class D3ForceDirectedRenderer extends React.Component<
       y: zoomTransform.y + (node.y + node.size / 2) * zoomTransform.k,
     };
 
-    if (nodeMax.x < 0) {
-      center.x += (nodeMin.x - panOffset) / zoomTransform.k;
-      moveToNode = true;
-    }
-    if (nodeMin.x > width) {
-      center.x += (nodeMax.x - width + panOffset) / zoomTransform.k;
-      moveToNode = true;
-    }
-    if (nodeMax.y < 0) {
-      center.y += (nodeMin.y - panOffset) / zoomTransform.k;
-      moveToNode = true;
-    }
-    if (nodeMin.y > height) {
-      center.y += (nodeMax.y - height + panOffset) / zoomTransform.k;
-      moveToNode = true;
+    return {
+      left: nodeMin.x,
+      right: nodeMax.x,
+      top: nodeMin.y,
+      bottom: nodeMax.y,
+    };
+  };
+
+  private makeNodeVisible = (nodeId) => {
+    const { nodesById } = this.state;
+    const node: ViewNode = nodesById[nodeId];
+
+    if (!node) {
+      return;
     }
 
-    if (moveToNode) {
-      this.zoom.translateTo(this.$svg, center.x, center.y);
+    this.makeBoxVisible(this.getNodeBoundingBox(node));
+  };
+
+  private makeGroupVisible = (groupId: string) => {
+    const { groupsById } = this.state;
+    const group: ViewGroup = groupsById[groupId];
+
+    const boundingBox = _.reduce(
+      group.nodes,
+      (box, node) => {
+        const nodeBox = this.getNodeBoundingBox(node);
+        return {
+          left: Math.min(nodeBox.left, box.left),
+          right: Math.max(nodeBox.right, box.right),
+          top: Math.min(nodeBox.top, box.top),
+          bottom: Math.max(nodeBox.bottom, box.bottom),
+        };
+      },
+      {
+        left: Number.POSITIVE_INFINITY,
+        right: Number.NEGATIVE_INFINITY,
+        top: Number.POSITIVE_INFINITY,
+        bottom: Number.NEGATIVE_INFINITY,
+      },
+    );
+
+    this.makeBoxVisible(boundingBox);
+  };
+
+  private makeSelectionVisible = () => {
+    const { selectedType, selected } = this.props;
+
+    if (selectedType === GraphElementType.node) {
+      this.makeNodeVisible(selected);
+      return;
     }
+
+    this.makeGroupVisible(selected);
   };
 
   private lockNodes = () => {
@@ -378,6 +442,16 @@ export default class D3ForceDirectedRenderer extends React.Component<
         .on('end', (d) => this.onNodeDragEnd(d))
         .filter(() => this.state.nodes.length > 1),
     );
+
+    $node.on('contextmenu', this.onNodeContextMenu);
+  };
+
+  onNodeContextMenu = (d: ViewNode) => {
+    const { contextMenu } = this.props;
+
+    if (contextMenu.open(GraphElementType.node, d.id, d3.event.pageX, d3.event.pageY)) {
+      d3.event.preventDefault();
+    }
   };
 
   private onNodeDragStart = () => {
@@ -462,11 +536,11 @@ export default class D3ForceDirectedRenderer extends React.Component<
     if (sourceGroup) {
       const title = targetGroup ? 'Move Component Node' : 'Remove Component Node from Application';
       const message = (
-        <React.Fragment>
+        <>
           Are you sure you want to {targetGroup ? 'move' : 'remove'} <strong>{d.name}</strong> from{' '}
           {groupsById[sourceGroup].name}
           {targetGroup ? ` to ${targetGroupName}` : ''}?
-        </React.Fragment>
+        </>
       );
       const btnText = targetGroup ? 'Move' : 'Remove';
 
@@ -507,6 +581,14 @@ export default class D3ForceDirectedRenderer extends React.Component<
             this.state.groupsById[this.state.groups[0]].nodes.length !== this.state.nodes.length,
         ),
     );
+    $group.on('contextmenu', this.onGroupContextMenu);
+  };
+
+  onGroupContextMenu = (d: ViewGroup) => {
+    const { contextMenu } = this.props;
+    if (contextMenu.open(GraphElementType.group, d.name, d3.event.pageX, d3.event.pageY)) {
+      d3.event.preventDefault();
+    }
   };
 
   private onGroupDragStart = (d: ViewGroup) => {
@@ -809,10 +891,58 @@ export default class D3ForceDirectedRenderer extends React.Component<
   private deselect = (e: React.MouseEvent) => {
     e.stopPropagation();
     if (this.props.selected) {
-      this.props.onSelect(null);
+      this.props.onSelect(null, null);
     }
   };
 
+  private isDragActive = (): boolean => {
+    const { dragNodeId, createConnection, moveConnection } = this.state;
+    return !!dragNodeId || !!moveConnection || (!!createConnection && createConnection.dragging);
+  };
+
+  private draggedEdges() {
+    const { dragNodeId, edgesById } = this.state;
+    if (!dragNodeId) {
+      return [];
+    }
+    const edges = _.filter(edgesById, (viewEdge: ViewEdge) => {
+      return viewEdge.source.id === dragNodeId || viewEdge.target.id === dragNodeId;
+    });
+    return _.map(edges, 'id');
+  }
+
+  private draggedNodes() {
+    const { dragNodeId, edgesById, nodes } = this.state;
+    if (!dragNodeId) {
+      return [];
+    }
+    const edges = _.filter(edgesById, (viewEdge: ViewEdge) => {
+      return viewEdge.source.id === dragNodeId || viewEdge.target.id === dragNodeId;
+    });
+
+    return _.filter(nodes, (nodeId: string) =>
+      _.find(edges, (edge: ViewEdge) => edge.source.id === nodeId || edge.target.id === nodeId),
+    );
+  }
+
+  private createGroupLinks(): any[] {
+    const { groups, groupsById } = this.state;
+    const groupLinks = [];
+    // link each node within a group together to form group clusters
+    groups.forEach((g) => {
+      const { nodes } = groupsById[g];
+      for (let i = 0; i < nodes.length; i++) {
+        for (let j = i + 1; j < nodes.length; j++) {
+          groupLinks.push({
+            source: nodes[i],
+            target: nodes[j],
+          });
+        }
+      }
+    });
+    return groupLinks;
+  }
+
   public api() {
     // eslint-disable-next-line @typescript-eslint/no-this-alias
     const self = this;
@@ -873,51 +1003,31 @@ export default class D3ForceDirectedRenderer extends React.Component<
     return api;
   }
 
-  private createGroupLinks(): any[] {
-    const { groups, groupsById } = this.state;
-    const groupLinks = [];
-    // link each node within a group together to form group clusters
-    groups.forEach((g) => {
-      const { nodes } = groupsById[g];
-      for (let i = 0; i < nodes.length; i++) {
-        for (let j = i + 1; j < nodes.length; j++) {
-          groupLinks.push({
-            source: nodes[i],
-            target: nodes[j],
-          });
-        }
-      }
-    });
-    return groupLinks;
-  }
+  renderGroup(groupId: string) {
+    const { groupProvider, onSelect, selectedType, selected } = this.props;
+    const { groupsById, sourceGroup, targetGroup } = this.state;
+    const viewGroup = groupsById[groupId];
+    const Component = groupProvider(viewGroup.type);
 
-  private draggedEdges() {
-    const { dragNodeId, edgesById } = this.state;
-    if (!dragNodeId) {
-      return [];
-    }
-    const edges = _.filter(edgesById, (viewEdge: ViewEdge) => {
-      return viewEdge.source.id === dragNodeId || viewEdge.target.id === dragNodeId;
-    });
-    return _.map(edges, 'id');
-  }
-
-  private draggedNodes() {
-    const { dragNodeId, edgesById, nodes } = this.state;
-    if (!dragNodeId) {
-      return [];
-    }
-    const edges = _.filter(edgesById, (viewEdge: ViewEdge) => {
-      return viewEdge.source.id === dragNodeId || viewEdge.target.id === dragNodeId;
-    });
-
-    return _.filter(nodes, (nodeId: string) =>
-      _.find(edges, (edge: ViewEdge) => edge.source.id === nodeId || edge.target.id === nodeId),
+    return (
+      <GroupWrapper
+        component={Component}
+        {...viewGroup}
+        key={groupId}
+        onEnter={this.onGroupEnter}
+        view={viewGroup}
+        onSelect={onSelect ? () => onSelect(GraphElementType.group, groupId) : null}
+        selected={selectedType === GraphElementType.group && selected === groupId}
+        dragActive={this.isDragActive()}
+        dropSource={groupId === sourceGroup}
+        dropTarget={groupId === targetGroup}
+        groupRef={(ref: GroupElementInterface) => this.refGroupSvg(ref, groupId)}
+      />
     );
   }
 
   renderNode(nodeId: string) {
-    const { nodeProvider, selected, onSelect, topology } = this.props;
+    const { nodeProvider, selected, selectedType, onSelect, topology } = this.props;
     const {
       nodesById,
       dragNodeId,
@@ -936,8 +1046,9 @@ export default class D3ForceDirectedRenderer extends React.Component<
         view={viewNode}
         data={data}
         key={nodeId}
-        selected={nodeId === selected}
-        onSelect={onSelect ? () => onSelect(nodeId) : null}
+        dragActive={this.isDragActive()}
+        selected={selectedType === GraphElementType.node && nodeId === selected}
+        onSelect={onSelect ? () => onSelect(GraphElementType.node, nodeId) : null}
         onEnter={this.onNodeEnter}
         onHover={(hovered: boolean) => this.onNodeHover(viewNode, hovered)}
         isDragging={
@@ -1006,33 +1117,31 @@ export default class D3ForceDirectedRenderer extends React.Component<
         {...viewEdge}
         key={edgeId}
         data={data}
+        dragActive={this.isDragActive()}
         isDragging={viewEdge.source.id === dragNodeId || viewEdge.target.id === dragNodeId}
         onTargetArrowEnter={this.onMoveConnectionEnter}
-        onRemove={() => onRemoveConnection(viewEdge.source.id, viewEdge.target.id)}
+        onRemove={() => onRemoveConnection(viewEdge.source.id, viewEdge.target.id, viewEdge.type)}
       />
     );
   }
 
   renderDragItems(edges, nodes) {
     return (
-      <React.Fragment>
+      <>
         {_.map(edges, (edgeId) => this.renderEdge(edgeId))}
         {_.map(nodes, (nodeId) => this.renderNode(nodeId))}
-      </React.Fragment>
+      </>
     );
   }
 
   render() {
-    const { width, height, groupProvider } = this.props;
+    const { width, height } = this.props;
     const {
       nodes,
       edges,
       groups,
-      groupsById,
       zoomTransform,
       dragNodeId,
-      sourceGroup,
-      targetGroup,
       createConnection,
       moveConnection,
     } = this.state;
@@ -1040,35 +1149,19 @@ export default class D3ForceDirectedRenderer extends React.Component<
     const draggedNodes = this.draggedNodes();
     const dragActive =
       dragNodeId || !!moveConnection || (createConnection && createConnection.dragging);
+
+    const className = classNames('odc-graph__svg', { 'odc-m-drag-active': dragActive });
     return (
       <svg
         height={height}
         width={width}
         ref={this.refSvg}
         onClick={this.deselect}
-        className={dragActive ? 'odc-m-drag-active' : ''}
+        className={className}
       >
-        <SvgDefsProvider>
+        <SVGDefsProvider>
           <g transform={zoomTransform && zoomTransform.toString()} ref={this.zoomGroup}>
-            <g>
-              {groups.map((groupId) => {
-                const viewGroup = groupsById[groupId];
-                const Component = groupProvider(viewGroup.type);
-
-                return (
-                  <GroupWrapper
-                    component={Component}
-                    {...viewGroup}
-                    key={groupId}
-                    onEnter={this.onGroupEnter}
-                    view={viewGroup}
-                    dropSource={groupId === sourceGroup}
-                    dropTarget={groupId === targetGroup}
-                    groupRef={(ref: GroupElementInterface) => this.refGroupSvg(ref, groupId)}
-                  />
-                );
-              })}
-            </g>
+            <g>{groups.map((groupId) => this.renderGroup(groupId))}</g>
             <g>
               {edges.map((edgeId) =>
                 _.includes(draggedEdges, edgeId) ? null : this.renderEdge(edgeId),
@@ -1083,7 +1176,7 @@ export default class D3ForceDirectedRenderer extends React.Component<
               {this.renderMoveConnection()}
             </g>
           </g>
-        </SvgDefsProvider>
+        </SVGDefsProvider>
       </svg>
     );
   }
@@ -1162,7 +1255,7 @@ class EdgeWrapper extends React.Component<EdgeWrapperProps> {
   componentDidUpdate(prevProps: EdgeWrapperProps) {
     if (prevProps.view !== this.props.view) {
       // we need to update the data so that d3 apis get the correct new edge
-      this.$targetArrow.datum(this.props.view);
+      this.$targetArrow && this.$targetArrow.datum(this.props.view);
     }
   }
 
