@@ -9,6 +9,8 @@ export const nodeProvider: NodeProvider = (type) => {
   switch (type) {
     case 'workload':
       return WorkloadNode;
+    case 'revision':
+      return WorkloadNode;
     default:
       return DefaultNode;
   }
@@ -18,6 +20,8 @@ export const edgeProvider: EdgeProvider = (type) => {
   switch (type) {
     case 'connects-to':
       return ConnectsTo;
+    case 'service-binding':
+      return ConnectsTo;
     default:
       return DefaultEdge;
   }
