@@ -1,6 +1,6 @@
 import * as React from 'react';
 import * as classNames from 'classnames';
-import { createSvgIdUrl } from '../../../utils/svg-utils';
+import { createSvgIdUrl } from '@console/topology';
 import { ViewNode } from '../topology-types';
 
 import './BaseEdge.scss';
