@@ -6,7 +6,8 @@ import {
   chart_color_black_400 as skippedColor,
   chart_color_black_500 as cancelledColor,
 } from '@patternfly/react-tokens';
-import { K8sResourceKind } from '@console/internal/module/k8s';
+import { K8sKind, K8sResourceKind, referenceForModel } from '@console/internal/module/k8s';
+import { ClusterTaskModel, PipelineRunModel, TaskModel } from '../models';
 import { pipelineRunFilterReducer } from './pipeline-filter-reducer';
 
 interface Metadata {
@@ -25,11 +26,21 @@ interface StatusMessage {
 }
 
 export interface TaskStatus {
-  Succeeded?: number;
-  Running?: number;
-  Failed?: number;
-  Notstarted?: number;
-  FailedToStart?: number;
+  PipelineNotStarted: number;
+  Pending: number;
+  Running: number;
+  Succeeded: number;
+  Cancelled: number;
+  Failed: number;
+}
+
+export interface PipelineTask {
+  name: string;
+  runAfter?: string[];
+  taskRef: {
+    kind?: string;
+    name: string;
+  };
 }
 
 export interface Resource {
@@ -55,19 +66,23 @@ export interface Pipeline extends K8sResourceKind {
   latestRun?: PipelineRun;
   spec?: {
     pipelineRef?: { name: string };
-    params: PipelineParam[];
-    resources: PipelineResource[];
-    tasks: K8sResourceKind[];
-    serviceAccountName?: string;
+    params?: PipelineParam[];
+    resources?: PipelineResource[];
+    tasks: PipelineTask[];
+    serviceAccount?: string;
   };
 }
 
 export interface PipelineRun extends K8sResourceKind {
   spec?: {
-    pipelineRef?: { name: string };
+    pipelineRef: { name: string };
     params?: PipelineRunParam[];
     resources?: PipelineResource[];
+    serviceAccount?: string;
     serviceAccountName?: string;
+    // Odd status value that only appears in a single case - cancelling a pipeline
+    status?: 'PipelineRunCancelled';
+    timeout?: string;
   };
   status?: {
     succeededCondition?: string;
@@ -75,7 +90,9 @@ export interface PipelineRun extends K8sResourceKind {
     conditions?: Condition[];
     startTime?: string;
     completionTime?: string;
-    taskRuns?: K8sResourceKind[];
+    taskRuns?: {
+      [key: string]: { pipelineTaskName?: string } & K8sResourceKind;
+    };
   };
 }
 
@@ -84,9 +101,10 @@ export interface Condition {
   status: string;
   reason?: string;
   message?: string;
+  lastTransitionTime?: string;
 }
 
-interface Param {
+export interface Param {
   name: string;
 }
 
@@ -117,7 +135,7 @@ export const getResources = (data: PropPipelineData[]): Resource => {
       if (pipeline.metadata && pipeline.metadata.namespace && pipeline.metadata.name) {
         propsReferenceForRuns.push(`PipelineRun_${i}`);
         resources.push({
-          kind: 'PipelineRun',
+          kind: referenceForModel(PipelineRunModel),
           namespace: pipeline.metadata.namespace,
           isList: true,
           prop: `PipelineRun_${i}`,
@@ -243,10 +261,14 @@ export const getTaskStatus = (pipelinerun: PipelineRun, pipeline: Pipeline): Tas
       ? Object.keys(pipelinerun.status.taskRuns)
       : [];
   const plrTaskLength = plrTasks.length;
-  const taskStatus: TaskStatus = {};
-  Object.keys(runStatus).forEach((key) => {
-    taskStatus[key] = 0;
-  });
+  const taskStatus: TaskStatus = {
+    PipelineNotStarted: 0,
+    Pending: 0,
+    Running: 0,
+    Succeeded: 0,
+    Failed: 0,
+    Cancelled: 0,
+  };
   if (pipelinerun && pipelinerun.status && pipelinerun.status.taskRuns) {
     plrTasks.forEach((taskRun) => {
       const status = pipelineRunFilterReducer(pipelinerun.status.taskRuns[taskRun]);
@@ -277,3 +299,11 @@ export const getTaskStatus = (pipelinerun: PipelineRun, pipeline: Pipeline): Tas
   }
   return taskStatus;
 };
+
+export const getResourceModelFromTask = (task: PipelineTask): K8sKind => {
+  const {
+    taskRef: { kind },
+  } = task;
+
+  return kind === ClusterTaskModel.kind ? ClusterTaskModel : TaskModel;
+};
