@@ -12,18 +12,18 @@ export const pipelineFilterReducer = (pipeline): string => {
   return pipeline.latestRun.status.succeededCondition;
 };
 
-export const pipelineRunFilterReducer = (pipelineRun): string => {
+export const pipelineRunStatus = (pipelineRun): string => {
   if (
     !pipelineRun ||
     !pipelineRun.status ||
     !pipelineRun.status.conditions ||
     pipelineRun.status.conditions.length === 0
   ) {
-    return '-';
+    return null;
   }
   const condition = pipelineRun.status.conditions.find((c) => c.type === 'Succeeded');
   return !condition || !condition.status
-    ? '-'
+    ? null
     : condition.status === 'True'
     ? 'Succeeded'
     : condition.status === 'False'
@@ -31,6 +31,11 @@ export const pipelineRunFilterReducer = (pipelineRun): string => {
     : 'Running';
 };
 
+export const pipelineRunFilterReducer = (pipelineRun): string => {
+  const status = pipelineRunStatus(pipelineRun);
+  return status || '-';
+};
+
 export const pipelineStatusFilter = (filters, pipeline) => {
   if (!filters || !filters.selected || !filters.selected.size) {
     return true;
