@@ -7,7 +7,15 @@ import {
   LOG_SOURCE_RUNNING,
   LOG_SOURCE_TERMINATED,
 } from '@console/internal/components/utils';
-import { PipelineParam, PipelineRunParam, runStatus } from './pipeline-augment';
+import {
+  getLatestRun,
+  Pipeline,
+  PipelineRun,
+  runStatus,
+  PipelineParam,
+  PipelineRunParam,
+} from './pipeline-augment';
+import { pipelineFilterReducer, pipelineRunStatus } from './pipeline-filter-reducer';
 
 interface Resources {
   inputs?: Resource[];
@@ -21,6 +29,7 @@ interface Resource {
 }
 
 export interface ContainerStatus {
+  name: string;
   lastState?: string;
   state?: {
     waiting?: Record<string, any>;
@@ -56,6 +65,18 @@ export const conditions = {
     task.runAfter && task.runAfter.length > 0,
 };
 
+export enum ListFilterId {
+  Running = 'Running',
+  Failed = 'Failed',
+  Succeeded = 'Succeeded',
+}
+
+export const ListFilterLabels = {
+  [ListFilterId.Running]: 'Running',
+  [ListFilterId.Failed]: 'Failed',
+  [ListFilterId.Succeeded]: 'Complete',
+};
+
 // to be used by both Pipeline and Pipelinerun visualisation
 const sortTasksByRunAfterAndFrom = (
   tasks: PipelineVisualizationTaskItem[],
@@ -137,7 +158,11 @@ const appendPipelineRunStatus = (pipeline, pipelineRun) => {
 
 export const getPipelineTasks = (
   pipeline: K8sResourceKind,
-  pipelineRun: K8sResourceKind = { apiVersion: '', metadata: {}, kind: 'PipelineRun' },
+  pipelineRun: K8sResourceKind = {
+    apiVersion: '',
+    metadata: {},
+    kind: 'PipelineRun',
+  },
 ): PipelineVisualizationTaskItem[][] => {
   // Each unit in 'out' array is termed as stage | out = [stage1 = [task1], stage2 = [task2,task3], stage3 = [task4]]
   const out = [];
@@ -151,7 +176,10 @@ export const getPipelineTasks = (
   // Step 2: Push all nodes without any dependencies in different stages
   tasks.forEach((task) => {
     if (!conditions.hasFromDependency(task) && !conditions.hasRunAfterDependency(task)) {
-      out.push([task]);
+      if (out.length === 0) {
+        out.push([]);
+      }
+      out[0].push(task);
     }
   });
 
@@ -231,6 +259,46 @@ export const containerToLogSourceStatus = (container: ContainerStatus): string =
   return LOG_SOURCE_RUNNING;
 };
 
+type CurrentPipelineStatus = {
+  currentPipeline: Pipeline;
+  status: string;
+};
+
+/**
+ * Takes a pipeline and a series of matching pipeline runs and produces a current pipeline state.
+ */
+export const constructCurrentPipeline = (
+  pipeline: Pipeline,
+  pipelineRuns: PipelineRun[],
+): CurrentPipelineStatus => {
+  if (!pipeline || !pipelineRuns || pipelineRuns.length === 0) {
+    // Not enough data to build the current state
+    return null;
+  }
+
+  const latestRun = getLatestRun({ data: pipelineRuns }, 'creationTimestamp');
+
+  if (!latestRun) {
+    // Without the latestRun we will not have progress to show
+    return null;
+  }
+
+  const currentPipeline: Pipeline = {
+    ...pipeline,
+    latestRun,
+  };
+
+  let status: string = pipelineFilterReducer(currentPipeline);
+  if (status === '-') {
+    status = runStatus.Pending;
+  }
+
+  return {
+    currentPipeline,
+    status,
+  };
+};
+
 export const getPipelineRunParams = (pipelineParams: PipelineParam[]): PipelineRunParam[] => {
   return (
     pipelineParams &&
@@ -240,3 +308,20 @@ export const getPipelineRunParams = (pipelineParams: PipelineParam[]): PipelineR
     }))
   );
 };
+
+export const pipelineRunDuration = (run: PipelineRun): string => {
+  const startTime = _.get(run, ['status', 'startTime'], null);
+  const completionTime = _.get(run, ['status', 'completionTime'], null);
+
+  // Duration cannot be computed if start time is missing or a completed/failed pipeline has no end time
+  if (!startTime || (!completionTime && pipelineRunStatus(run) !== 'Running')) {
+    return '-';
+  }
+  const start = new Date(startTime).getTime();
+
+  // For running pipelines duration must be current time - starttime.
+  const duration = completionTime
+    ? new Date(completionTime).getTime() - start
+    : new Date().getTime() - start;
+  return formatDuration(duration);
+};
