@@ -1,45 +1,38 @@
-import { k8sCreate, K8sResourceKind, referenceForModel } from '@console/internal/module/k8s';
+import { K8sResourceKind, referenceForModel } from '@console/internal/module/k8s';
 import { FirehoseResource } from '@console/internal/components/utils';
 import {
   ServiceModel,
   RevisionModel,
   ConfigurationModel,
   RouteModel,
+  EventSourceCronJobModel,
+  EventSourceContainerModel,
+  EventSourceApiServerModel,
+  EventSourceCamelModel,
+  EventSourceKafkaModel,
 } from '@console/knative-plugin';
 import { getAppLabels } from '@console/dev-console/src/utils/resource-label-utils';
+import {
+  DeployImageFormData,
+  GitImportFormData,
+} from '@console/dev-console/src/components/import/import-types';
 
-interface ServerlessScaling {
-  minpods: number;
-  maxpods: number | '';
-  concurrencytarget: number | '';
-  concurrencylimit: number | '';
-}
-
-interface LimitsData {
-  cpu: ResourceType;
-  memory: ResourceType;
-}
-
-interface ResourceType {
-  request: number | string;
-  requestUnit: string;
-  limit: number | string;
-  limitUnit: string;
-}
-
-export const createKnativeService = (
-  name: string,
-  applicationName: string,
-  namespace: string,
-  scaling: ServerlessScaling,
-  limits: LimitsData,
-  unknownTargetPort,
-  labels,
+export const getKnativeServiceDepResource = (
+  formData: GitImportFormData | DeployImageFormData,
   imageStreamUrl: string,
   imageStreamName?: string,
   annotations?: { [name: string]: string },
-  imageTag?: string,
-): Promise<K8sResourceKind> => {
+): K8sResourceKind => {
+  const {
+    name,
+    application: { name: applicationName },
+    project: { name: namespace },
+    serverless: { scaling },
+    limits,
+    route: { unknownTargetPort, create },
+    labels,
+    image: { tag: imageTag },
+  } = formData;
   const contTargetPort: number = parseInt(unknownTargetPort, 10);
   const { concurrencylimit, concurrencytarget, minpods, maxpods } = scaling;
   const {
@@ -64,6 +57,11 @@ export const createKnativeService = (
     metadata: {
       name,
       namespace,
+      labels: {
+        ...defaultLabel,
+        ...labels,
+        ...(!create && { 'serving.knative.dev/visibility': `cluster-local` }),
+      },
     },
     spec: {
       template: {
@@ -113,8 +111,7 @@ export const createKnativeService = (
       },
     },
   };
-
-  return k8sCreate(ServiceModel, knativeDeployResource);
+  return knativeDeployResource;
 };
 
 export const knativeServingResourcesRevision = (namespace: string): FirehoseResource[] => {
@@ -156,11 +153,8 @@ export const knativeServingResourcesRoutes = (namespace: string): FirehoseResour
   return knativeResource;
 };
 
-export const knativeServingResources = (namespace: string): FirehoseResource[] => {
+export const knativeServingResourcesServices = (namespace: string): FirehoseResource[] => {
   const knativeResource = [
-    ...knativeServingResourcesRevision(namespace),
-    ...knativeServingResourcesConfigurations(namespace),
-    ...knativeServingResourcesRoutes(namespace),
     {
       isList: true,
       kind: referenceForModel(ServiceModel),
@@ -171,3 +165,68 @@ export const knativeServingResources = (namespace: string): FirehoseResource[] =
   ];
   return knativeResource;
 };
+
+export const eventSourceResourcesCronJob = (namespace: string): FirehoseResource[] => {
+  const knativeResource = [
+    {
+      isList: true,
+      kind: referenceForModel(EventSourceCronJobModel),
+      namespace,
+      prop: 'eventSourceCronjob',
+      optional: true,
+    },
+  ];
+  return knativeResource;
+};
+
+export const eventSourceResourcesContainer = (namespace: string): FirehoseResource[] => {
+  const knativeResource = [
+    {
+      isList: true,
+      kind: referenceForModel(EventSourceContainerModel),
+      namespace,
+      prop: 'eventSourceContainers',
+      optional: true,
+    },
+  ];
+  return knativeResource;
+};
+
+export const eventSourceResourcesApiServer = (namespace: string): FirehoseResource[] => {
+  const knativeResource = [
+    {
+      isList: true,
+      kind: referenceForModel(EventSourceApiServerModel),
+      namespace,
+      prop: 'eventSourceApiserver',
+      optional: true,
+    },
+  ];
+  return knativeResource;
+};
+
+export const eventSourceResourcesCamel = (namespace: string): FirehoseResource[] => {
+  const knativeResource = [
+    {
+      isList: true,
+      kind: referenceForModel(EventSourceCamelModel),
+      namespace,
+      prop: 'eventSourceCamel',
+      optional: true,
+    },
+  ];
+  return knativeResource;
+};
+
+export const eventSourceResourcesKafka = (namespace: string): FirehoseResource[] => {
+  const knativeResource = [
+    {
+      isList: true,
+      kind: referenceForModel(EventSourceKafkaModel),
+      namespace,
+      prop: 'eventSourceKafka',
+      optional: true,
+    },
+  ];
+  return knativeResource;
+};
