@@ -2,7 +2,7 @@ import * as _ from 'lodash';
 import { ANNOTATION_FIRST_BOOT, BOOT_ORDER_FIRST, BOOT_ORDER_SECOND } from '../../../constants/vm';
 import { getBootDeviceIndex, getDisks, getInterfaces } from '../../../selectors/vm';
 import { VMKind } from '../../../types/vm';
-import { patchSafeValue } from '../../utils';
+import { patchSafeValue } from '../../utils/patch';
 
 export const getPxeBootPatch = (vm: VMKind) => {
   const patches = [];
