@@ -58,3 +58,37 @@ export type VMKind = {
   spec: VMSpec;
   status: VMStatus;
 } & K8sResourceKind;
+
+export type CPU = {
+  sockets: number;
+  cores: number;
+  threads: number;
+};
+
+export type CPURaw =
+  | {
+      sockets: string;
+      cores: string;
+      threads: string;
+    }
+  | string;
+
+export type V1NetworkInterface = {
+  name?: string;
+  model?: string;
+  macAddress?: string;
+  bootOrder?: number;
+  bridge?: {};
+  masquerade?: {};
+  sriov?: {};
+  slirp?: {};
+};
+
+export type V1Network = {
+  name?: string;
+  multus?: {
+    networkName: string;
+  };
+  pod?: {};
+  genie?: {};
+};
