@@ -1,34 +1,27 @@
 import * as React from 'react';
 import * as _ from 'lodash';
 import { getInfrastructurePlatform } from '@console/shared';
-import {
-  DashboardCard,
-  DashboardCardBody,
-  DashboardCardHeader,
-  DashboardCardTitle,
-} from '@console/internal/components/dashboard/dashboard-card';
-import { DetailsBody, DetailItem } from '@console/internal/components/dashboard/details-card';
+import DashboardCard from '@console/shared/src/components/dashboard/dashboard-card/DashboardCard';
+import DashboardCardBody from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardBody';
+import DashboardCardHeader from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardHeader';
+import DashboardCardTitle from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardTitle';
+import DetailsBody from '@console/shared/src/components/dashboard/details-card/DetailsBody';
+import DetailItem from '@console/shared/src/components/dashboard/details-card/DetailItem';
 import {
   DashboardItemProps,
   withDashboardResources,
-} from '@console/internal/components/dashboards-page/with-dashboard-resources';
+} from '@console/internal/components/dashboard/with-dashboard-resources';
 import { FirehoseResource, ExternalLink, FirehoseResult } from '@console/internal/components/utils';
-import { InfrastructureModel, SubscriptionModel } from '@console/internal/models/index';
-import { referenceForModel, K8sResourceKind } from '@console/internal/module/k8s';
+import { InfrastructureModel } from '@console/internal/models/index';
+import { SubscriptionModel } from '@console/operator-lifecycle-manager/src/models';
+import { referenceForModel, K8sResourceKind, k8sGet } from '@console/internal/module/k8s';
+import { PrometheusResponse } from '@console/internal/components/graphs';
 import { getOCSVersion } from '@console/ceph-storage-plugin/src/selectors';
 import { getMetric } from '../../utils';
 
 const NOOBAA_SYSTEM_NAME_QUERY = 'NooBaa_system_info';
 const NOOBAA_DASHBOARD_LINK_QUERY = 'NooBaa_system_links';
 
-const infrastructureResource: FirehoseResource = {
-  kind: referenceForModel(InfrastructureModel),
-  namespaced: false,
-  name: 'cluster',
-  isList: false,
-  prop: 'infrastructure',
-};
-
 const SubscriptionResource: FirehoseResource = {
   kind: referenceForModel(SubscriptionModel),
   namespaced: false,
@@ -44,29 +37,48 @@ export const ObjectServiceDetailsCard: React.FC<DashboardItemProps> = ({
   prometheusResults,
   resources,
 }) => {
+  const [infrastructure, setInfrastructure] = React.useState<K8sResourceKind>();
+  const [infrastructureError, setInfrastructureError] = React.useState();
+  React.useEffect(() => {
+    const fetchInfrastructure = async () => {
+      try {
+        const infra = await k8sGet(InfrastructureModel, 'cluster');
+        setInfrastructure(infra);
+      } catch (error) {
+        setInfrastructureError(error);
+      }
+    };
+    fetchInfrastructure();
+  }, []);
   React.useEffect(() => {
     watchK8sResource(SubscriptionResource);
-    watchK8sResource(infrastructureResource);
     watchPrometheus(NOOBAA_SYSTEM_NAME_QUERY);
     watchPrometheus(NOOBAA_DASHBOARD_LINK_QUERY);
     return () => {
       stopWatchK8sResource(SubscriptionResource);
-      stopWatchK8sResource(infrastructureResource);
       stopWatchPrometheusQuery(NOOBAA_SYSTEM_NAME_QUERY);
       stopWatchPrometheusQuery(NOOBAA_DASHBOARD_LINK_QUERY);
     };
   }, [watchK8sResource, stopWatchK8sResource, watchPrometheus, stopWatchPrometheusQuery]);
 
-  const systemResult = prometheusResults.getIn([NOOBAA_SYSTEM_NAME_QUERY, 'result']);
-  const dashboardLinkResult = prometheusResults.getIn([NOOBAA_DASHBOARD_LINK_QUERY, 'result']);
+  const systemResult = prometheusResults.getIn([
+    NOOBAA_SYSTEM_NAME_QUERY,
+    'data',
+  ]) as PrometheusResponse;
+  const dashboardLinkResult = prometheusResults.getIn([
+    NOOBAA_DASHBOARD_LINK_QUERY,
+    'data',
+  ]) as PrometheusResponse;
+  const systemLoadError = prometheusResults.getIn([NOOBAA_SYSTEM_NAME_QUERY, 'loadError']);
+  const dashboardLinkLoadError = prometheusResults.getIn([
+    NOOBAA_DASHBOARD_LINK_QUERY,
+    'loadError',
+  ]);
 
   const systemName = getMetric(systemResult, 'system_name');
   const systemLink = getMetric(dashboardLinkResult, 'dashboard');
 
-  const infrastructure = _.get(resources, 'infrastructure');
-  const infrastructureLoaded = _.get(infrastructure, 'loaded', false);
-  const infrastructureData = _.get(infrastructure, 'data') as K8sResourceKind;
-  const infrastructurePlatform = getInfrastructurePlatform(infrastructureData);
+  const infrastructurePlatform = getInfrastructurePlatform(infrastructure);
 
   const subscription = _.get(resources, 'subscription') as FirehoseResult;
   const subscriptionLoaded = _.get(subscription, 'loaded');
@@ -80,21 +92,21 @@ export const ObjectServiceDetailsCard: React.FC<DashboardItemProps> = ({
       <DashboardCardBody>
         <DetailsBody>
           <DetailItem key="service_name" title="Service Name" error={false} isLoading={false}>
-            OpenShift Container Storage
+            OpenShift Container Storage (OCS)
           </DetailItem>
           <DetailItem
             key="system_name"
             title="System Name"
             isLoading={!systemResult || !dashboardLinkResult}
-            error={!systemName || !systemLink}
+            error={systemLoadError || dashboardLinkLoadError || !systemName || !systemLink}
           >
             <ExternalLink href={systemLink} text={systemName} />
           </DetailItem>
           <DetailItem
             key="provider"
             title="Provider"
-            error={!infrastructurePlatform}
-            isLoading={!infrastructureLoaded}
+            error={!!infrastructureError || (infrastructure && !infrastructurePlatform)}
+            isLoading={!infrastructure}
           >
             {infrastructurePlatform}
           </DetailItem>
@@ -102,7 +114,7 @@ export const ObjectServiceDetailsCard: React.FC<DashboardItemProps> = ({
             key="version"
             title="Version"
             isLoading={!subscriptionLoaded}
-            error={!ocsVersion}
+            error={subscriptionLoaded && !ocsVersion}
           >
             {ocsVersion}
           </DetailItem>
