@@ -22,7 +22,7 @@ import {
   referenceForModel,
   ResourceAccessReviewRequest,
 } from '../module/k8s';
-import { connectToFlags } from '../reducers/features';
+import { connectToFlags, FlagsObject } from '../reducers/features';
 import { RootState } from '../redux';
 import { CheckBox, CheckBoxControls } from './row-filter';
 import { DefaultPage } from './default-resource';
@@ -64,26 +64,42 @@ const getAPIResourceLink = (activeNamespace: string, model: K8sKind) => {
   return `/api-resource/ns/${activeNamespace}/${ref}`;
 };
 
-const APIResourceLink_: React.FC<APIResourceLinkStateProps & APIResourceLinkOwnProps> = ({activeNamespace, model}) => {
+const APIResourceLink_: React.FC<APIResourceLinkStateProps & APIResourceLinkOwnProps> = ({
+  activeNamespace,
+  model,
+}) => {
   const to = getAPIResourceLink(activeNamespace, model);
-  return <span className="co-resource-item">
-    <span className="co-resource-icon--fixed-width hidden-xs"><ResourceIcon kind={referenceForModel(model)} /></span>
-    <Link to={to} className="co-resource-item__resource-name">{model.kind}</Link>
-  </span>;
+  return (
+    <span className="co-resource-item">
+      <span className="co-resource-icon--fixed-width hidden-xs">
+        <ResourceIcon kind={referenceForModel(model)} />
+      </span>
+      <Link to={to} className="co-resource-item__resource-name">
+        {model.kind}
+      </Link>
+    </span>
+  );
 };
-const APIResourceLink = connect<APIResourceLinkStateProps, {}, APIResourceLinkOwnProps>(mapStateToProps)(APIResourceLink_);
+const APIResourceLink = connect<APIResourceLinkStateProps, {}, APIResourceLinkOwnProps>(
+  mapStateToProps,
+)(APIResourceLink_);
 
 const EmptyAPIResourcesMsg: React.FC<{}> = () => <EmptyBox label="API Resources" />;
 
-const Group: React.FC<{value: string}> = ({value}) => {
+const Group: React.FC<{ value: string }> = ({ value }) => {
   if (!value) {
     return <>-</>;
   }
 
   const [first, ...rest] = value.split('.');
-  return _.isEmpty(rest)
-    ? <>{value}</>
-    : <>{first}<span className="text-muted">.{rest.join('.')}</span></>;
+  return _.isEmpty(rest) ? (
+    <>{value}</>
+  ) : (
+    <>
+      {first}
+      <span className="text-muted">.{rest.join('.')}</span>
+    </>
+  );
 };
 
 const tableClasses = [
@@ -94,53 +110,73 @@ const tableClasses = [
   'col-lg-3 col-md-5 hidden-sm hidden-xs',
 ];
 
-const APIResourceHeader = () => [{
-  title: 'Kind',
-  sortField: 'kind',
-  transforms: [sortable],
-  props: { className: tableClasses[0] },
-}, {
-  title: 'Group',
-  sortField: 'apiGroup',
-  transforms: [sortable],
-  props: { className: tableClasses[1] },
-}, {
-  title: 'Version',
-  sortField: 'apiVersion',
-  transforms: [sortable],
-  props: { className: tableClasses[2] },
-}, {
-  title: 'Namespaced',
-  sortField: 'namespaced',
-  transforms: [sortable],
-  props: { className: tableClasses[3] },
-}, {
-  title: 'Description',
-  props: { className: tableClasses[4] },
-}];
+const APIResourceHeader = () => [
+  {
+    title: 'Kind',
+    sortField: 'kind',
+    transforms: [sortable],
+    props: { className: tableClasses[0] },
+  },
+  {
+    title: 'Group',
+    sortField: 'apiGroup',
+    transforms: [sortable],
+    props: { className: tableClasses[1] },
+  },
+  {
+    title: 'Version',
+    sortField: 'apiVersion',
+    transforms: [sortable],
+    props: { className: tableClasses[2] },
+  },
+  {
+    title: 'Namespaced',
+    sortField: 'namespaced',
+    transforms: [sortable],
+    props: { className: tableClasses[3] },
+  },
+  {
+    title: 'Description',
+    props: { className: tableClasses[4] },
+  },
+];
 
-const APIResourceRows = ({componentProps: {data}}) => _.map(data, (model: K8sKind) => [{
-  title: <APIResourceLink model={model} />,
-  props: { className: tableClasses[0] },
-}, {
-  title: <span className="co-select-to-copy"><Group value={model.apiGroup} /></span>,
-  props: { className: tableClasses[1] },
-}, {
-  title: model.apiVersion,
-  props: { className: tableClasses[2] },
-}, {
-  title: model.namespaced ? 'true' : 'false',
-  props: { className: tableClasses[3] },
-}, {
-  title: <div className="co-line-clamp">{getResourceDescription(model)}</div>,
-  props: { className: tableClasses[4] },
-}]);
+const APIResourceRows = ({ componentProps: { data } }) =>
+  _.map(data, (model: K8sKind) => [
+    {
+      title: <APIResourceLink model={model} />,
+      props: { className: tableClasses[0] },
+    },
+    {
+      title: (
+        <span className="co-select-to-copy">
+          <Group value={model.apiGroup} />
+        </span>
+      ),
+      props: { className: tableClasses[1] },
+    },
+    {
+      title: model.apiVersion,
+      props: { className: tableClasses[2] },
+    },
+    {
+      title: model.namespaced ? 'true' : 'false',
+      props: { className: tableClasses[3] },
+    },
+    {
+      title: <div className="co-line-clamp">{getResourceDescription(model)}</div>,
+      props: { className: tableClasses[4] },
+    },
+  ]);
 
-const stateToProps = ({k8s}) => ({
+const stateToProps = ({ k8s }) => ({
   models: k8s.getIn(['RESOURCES', 'models']),
 });
 
-const APIResourcesList = compose(withRouter, connect<APIResourcesListPropsFromState>(stateToProps))(({models, location}) => {
+const APIResourcesList = compose(
+  withRouter,
+  connect<APIResourcesListPropsFromState>(stateToProps),
+)(({ models, location }) => {
   const ALL = '#all#';
   const GROUP_PARAM = 'g';
   const VERSION_PARAM = 'v';
@@ -154,14 +190,17 @@ const APIResourcesList = compose(withRouter, connect<APIResourcesListPropsFromSt
   const scopeFilter = search.get(SCOPE_PARAM) || ALL;
 
   // group options
-  const groups: Set<string> = models.reduce((result: Set<string>, {apiGroup}) => {
+  const groups: Set<string> = models.reduce((result: Set<string>, { apiGroup }) => {
     return apiGroup ? result.add(apiGroup) : result;
   }, new Set<string>());
   const sortedGroups: string[] = [...groups].sort();
-  const groupOptions = sortedGroups.reduce((result, group: string) => {
-    result[group] = <Group value={group} />;
-    return result;
-  }, {[ALL]: 'All Groups', '': 'No Group'});
+  const groupOptions = sortedGroups.reduce(
+    (result, group: string) => {
+      result[group] = <Group value={group} />;
+      return result;
+    },
+    { [ALL]: 'All Groups', '': 'No Group' },
+  );
 
   const groupSpacer = new Set<string>();
   if (sortedGroups.length) {
@@ -173,14 +212,17 @@ const APIResourcesList = compose(withRouter, connect<APIResourcesListPropsFromSt
   };
 
   // version options
-  const versions: Set<string> = models.reduce((result: Set<string>, {apiVersion}) => {
+  const versions: Set<string> = models.reduce((result: Set<string>, { apiVersion }) => {
     return result.add(apiVersion);
   }, new Set<string>());
   const sortedVersions: string[] = [...versions].sort();
-  const versionOptions = sortedVersions.reduce((result, version: string) => {
-    result[version] = version;
-    return result;
-  }, {[ALL]: 'All Versions'});
+  const versionOptions = sortedVersions.reduce(
+    (result, version: string) => {
+      result[version] = version;
+      return result;
+    },
+    { [ALL]: 'All Versions' },
+  );
 
   const versionSpacer = new Set<string>();
   if (sortedVersions.length) {
@@ -189,13 +231,13 @@ const APIResourcesList = compose(withRouter, connect<APIResourcesListPropsFromSt
 
   const scopeOptions = {
     [ALL]: 'All Scopes',
-    'cluster': 'Cluster',
-    'namespace': 'Namespace',
+    cluster: 'Cluster',
+    namespace: 'Namespace',
   };
   const scopeSpacer = new Set<string>(['cluster']);
 
   // filter by group, version, or text
-  const filteredResources = models.filter(({kind, apiGroup, apiVersion, namespaced}) => {
+  const filteredResources = models.filter(({ kind, apiGroup, apiVersion, namespaced }) => {
     if (groupFilter !== ALL && (apiGroup || '') !== groupFilter) {
       return false;
     }
@@ -220,7 +262,11 @@ const APIResourcesList = compose(withRouter, connect<APIResourcesListPropsFromSt
   });
 
   // Put models with no API group (core k8s resources) at the top.
-  const sortedResources = _.sortBy(filteredResources.toArray(), [({apiGroup}) => apiGroup || '1', 'apiVersion', 'kind']);
+  const sortedResources = _.sortBy(filteredResources.toArray(), [
+    ({ apiGroup }) => apiGroup || '1',
+    'apiVersion',
+    'kind',
+  ]);
 
   const updateURL = (k: string, v: string) => {
     if (v === ALL) {
@@ -240,71 +286,75 @@ const APIResourcesList = compose(withRouter, connect<APIResourcesListPropsFromSt
     }
   };
 
-  return <>
-    <div className="co-m-pane__filter-bar">
-      <div className="co-m-pane__filter-bar-group">
-        <Dropdown
-          autocompleteFilter={autocompleteGroups}
-          items={groupOptions}
-          onChange={onGroupSelected}
-          selectedKey={groupFilter}
-          spacerBefore={groupSpacer}
-          title={groupOptions[groupFilter]}
-          className="btn-group"
-        />
-        <Dropdown
-          items={versionOptions}
-          onChange={onVersionSelected}
-          selectedKey={versionFilter}
-          spacerBefore={versionSpacer}
-          title={versionOptions[versionFilter]}
-          className="btn-group"
-        />
-        <Dropdown
-          items={scopeOptions}
-          onChange={onScopeSelected}
-          selectedKey={scopeFilter}
-          spacerBefore={scopeSpacer}
-          title={scopeOptions[scopeFilter]}
-          className="btn-group"
+  return (
+    <>
+      <div className="co-m-pane__filter-bar">
+        <div className="co-m-pane__filter-bar-group">
+          <Dropdown
+            autocompleteFilter={autocompleteGroups}
+            items={groupOptions}
+            onChange={onGroupSelected}
+            selectedKey={groupFilter}
+            spacerBefore={groupSpacer}
+            title={groupOptions[groupFilter]}
+            className="btn-group"
+          />
+          <Dropdown
+            items={versionOptions}
+            onChange={onVersionSelected}
+            selectedKey={versionFilter}
+            spacerBefore={versionSpacer}
+            title={versionOptions[versionFilter]}
+            className="btn-group"
+          />
+          <Dropdown
+            items={scopeOptions}
+            onChange={onScopeSelected}
+            selectedKey={scopeFilter}
+            spacerBefore={scopeSpacer}
+            title={scopeOptions[scopeFilter]}
+            className="btn-group"
+          />
+        </div>
+        <div className="co-m-pane__filter-bar-group co-m-pane__filter-bar-group--filter">
+          <TextFilter
+            value={textFilter}
+            label="by kind"
+            onChange={(e) => setTextFilter(e.target.value)}
+          />
+        </div>
+      </div>
+      <div className="co-m-pane__body">
+        <Table
+          EmptyMsg={EmptyAPIResourcesMsg}
+          Header={APIResourceHeader}
+          Rows={APIResourceRows}
+          aria-label="API Resources"
+          data={sortedResources}
+          loaded={!!models.size}
+          virtualize={false}
         />
       </div>
-      <div className="co-m-pane__filter-bar-group co-m-pane__filter-bar-group--filter">
-        <TextFilter
-          value={textFilter}
-          label="by kind"
-          onChange={(e) => setTextFilter(e.target.value)}
-        />
-      </div>
-    </div>
-    <div className="co-m-pane__body">
-      <Table
-        EmptyMsg={EmptyAPIResourcesMsg}
-        Header={APIResourceHeader}
-        Rows={APIResourceRows}
-        aria-label="API Resources"
-        data={sortedResources}
-        loaded={!!models.size}
-        virtualize={false}
-      />
-    </div>
-  </>;
+    </>
+  );
 });
 APIResourcesList.displayName = 'APIResourcesList';
 
-export const APIExplorerPage: React.FC<{}> = () => <>
-  <Helmet>
-    <title>Explore API Resources</title>
-  </Helmet>
-  <div className="co-m-nav-title">
-    <h1 className="co-m-pane__heading">Explore API Resources</h1>
-  </div>
-  <APIResourcesList />
-</>;
+export const APIExplorerPage: React.FC<{}> = () => (
+  <>
+    <Helmet>
+      <title>Explore API Resources</title>
+    </Helmet>
+    <div className="co-m-nav-title">
+      <h1 className="co-m-pane__heading">Explore API Resources</h1>
+    </div>
+    <APIResourcesList />
+  </>
+);
 APIExplorerPage.displayName = 'APIExplorerPage';
 
-const APIResourceOverview: React.FC<APIResourceTabProps> = ({customData: {kindObj}}) => {
-  const {kind, apiGroup, apiVersion, namespaced, verbs, shortNames} = kindObj;
+const APIResourceOverview: React.FC<APIResourceTabProps> = ({ customData: { kindObj } }) => {
+  const { kind, apiGroup, apiVersion, namespaced, verbs, shortNames } = kindObj;
   const description = getResourceDescription(kindObj);
   return (
     <div className="co-m-pane__body">
@@ -332,7 +382,9 @@ const APIResourceOverview: React.FC<APIResourceTabProps> = ({customData: {kindOb
         {description && (
           <>
             <dt>Description</dt>
-            <dd className="co-break-word co-pre-line"><LinkifyExternal>{description}</LinkifyExternal></dd>
+            <dd className="co-break-word co-pre-line">
+              <LinkifyExternal>{description}</LinkifyExternal>
+            </dd>
           </>
         )}
       </dl>
@@ -340,54 +392,79 @@ const APIResourceOverview: React.FC<APIResourceTabProps> = ({customData: {kindOb
   );
 };
 
-const scrollTop = () => document.getElementById('content-scrollable').scrollTop = 0;
-const APIResourceSchema: React.FC<APIResourceTabProps> = ({customData: {kindObj}}) => {
+const scrollTop = () => (document.getElementById('content-scrollable').scrollTop = 0);
+const APIResourceSchema: React.FC<APIResourceTabProps> = ({ customData: { kindObj } }) => {
   return (
-    <div className="co-m-pane__body co-m-pane__body--no-top-margin">
+    <div className="co-m-pane__body">
       <ExploreType kindObj={kindObj} scrollTop={scrollTop} />
     </div>
   );
 };
 
-const APIResourceInstances: React.FC<APIResourceTabProps> = ({customData: {kindObj, namespace}}) => {
-  const componentLoader = resourceListPages.get(referenceForModel(kindObj), () => Promise.resolve(DefaultPage));
+const APIResourceInstances: React.FC<APIResourceTabProps> = ({
+  customData: { kindObj, namespace },
+}) => {
+  const componentLoader = resourceListPages.get(referenceForModel(kindObj), () =>
+    Promise.resolve(DefaultPage),
+  );
   const ns = kindObj.namespaced ? namespace : undefined;
 
-  return <AsyncComponent loader={componentLoader} namespace={ns} kind={kindObj.crd ? referenceForModel(kindObj) : kindObj.kind} showTitle={false} autoFocus={false} />;
+  return (
+    <AsyncComponent
+      loader={componentLoader}
+      namespace={ns}
+      kind={kindObj.crd ? referenceForModel(kindObj) : kindObj.kind}
+      showTitle={false}
+      autoFocus={false}
+    />
+  );
 };
 
-const Subject: React.FC<{value: string}> = ({value}) => {
+const Subject: React.FC<{ value: string }> = ({ value }) => {
   const [first, ...rest] = value.split(':');
-  return first === 'system' && !_.isEmpty(rest)
-    ? (
-      <>
-        <span className="text-muted">{first}:</span>
-        {rest.join(':')}
-      </>
-    )
-    : <>{value}</>;
+  return first === 'system' && !_.isEmpty(rest) ? (
+    <>
+      <span className="text-muted">{first}:</span>
+      {rest.join(':')}
+    </>
+  ) : (
+    <>{value}</>
+  );
 };
 
-const AccessTableHeader = () => [{
-  title: 'Subject',
-  sortField: 'name',
-  transforms: [sortable],
-}, {
-  title: 'Type',
-  sortField: 'type',
-  transforms: [sortable],
-}];
+const AccessTableHeader = () => [
+  {
+    title: 'Subject',
+    sortField: 'name',
+    transforms: [sortable],
+  },
+  {
+    title: 'Type',
+    sortField: 'type',
+    transforms: [sortable],
+  },
+];
 
-const AccessTableRows = ({componentProps: {data}}) => _.map(data, (subject) => [{
-  title: <span className="co-break-word co-select-to-copy"><Subject value={subject.name} /></span>,
-}, {
-  title: subject.type,
-}]);
+const AccessTableRows = ({ componentProps: { data } }) =>
+  _.map(data, (subject) => [
+    {
+      title: (
+        <span className="co-break-word co-select-to-copy">
+          <Subject value={subject.name} />
+        </span>
+      ),
+    },
+    {
+      title: subject.type,
+    },
+  ]);
 
 const EmptyAccessReviewMsg: React.FC<{}> = () => <EmptyBox label="Subjects" />;
 
-const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({customData: {kindObj, namespace}}) => {
-  const {apiGroup, apiVersion, namespaced, plural, verbs} = kindObj;
+const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({
+  customData: { kindObj, namespace },
+}) => {
+  const { apiGroup, apiVersion, namespaced, plural, verbs } = kindObj;
 
   // state
   const [verb, setVerb] = React.useState(_.first(verbs));
@@ -401,7 +478,9 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({customData: {ki
   // perform the access review
   React.useEffect(() => {
     setError(null);
-    const accessReviewModel = namespace ? LocalResourceAccessReviewsModel : ResourceAccessReviewsModel;
+    const accessReviewModel = namespace
+      ? LocalResourceAccessReviewsModel
+      : ResourceAccessReviewsModel;
     const req: ResourceAccessReviewRequest = {
       apiVersion: apiVersionForModel(accessReviewModel),
       kind: accessReviewModel.kind,
@@ -417,7 +496,13 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({customData: {ki
   }, [apiGroup, apiVersion, plural, namespace, verb]);
 
   if (error) {
-    return <LoadError message={error.message} label="Access Review" className="loading-box loading-box__errored" />;
+    return (
+      <LoadError
+        message={error.message}
+        label="Access Review"
+        className="loading-box loading-box__errored"
+      />
+    );
   }
 
   if (!accessResponse) {
@@ -429,9 +514,9 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({customData: {ki
   const serviceAccounts = [];
   _.each(accessResponse.users, (name: string) => {
     if (name.startsWith('system:serviceaccount:')) {
-      serviceAccounts.push({name, type: 'ServiceAccount'});
+      serviceAccounts.push({ name, type: 'ServiceAccount' });
     } else {
-      users.push({name, type: 'User'});
+      users.push({ name, type: 'User' });
     }
   });
   const groups = _.map(accessResponse.groups, (name: string) => ({ name, type: 'Group' }));
@@ -446,11 +531,12 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({customData: {ki
   const allSelected = showUsers && showGroups && showServiceAccounts;
   const itemCount = accessResponse.users.length + accessResponse.groups.length;
   const selectedCount = data.length;
-  const filteredData = data.filter(({name}: {name: string}) => fuzzy(filter, name));
+  const filteredData = data.filter(({ name }: { name: string }) => fuzzy(filter, name));
   const sortedData = _.orderBy(filteredData, ['type', 'name'], ['asc', 'asc']);
 
   // event handlers
-  const onFilterChange: React.ReactEventHandler<HTMLInputElement> = (e) => setFilter(e.currentTarget.value);
+  const onFilterChange: React.ReactEventHandler<HTMLInputElement> = (e) =>
+    setFilter(e.currentTarget.value);
   const toggleShowUsers = (e: React.MouseEvent<HTMLAnchorElement>) => {
     e.preventDefault();
     setShowUsers(!showUsers);
@@ -482,11 +568,7 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({customData: {ki
           />
         </div>
         <div className="co-m-pane__filter-bar-group co-m-pane__filter-bar-group--filter">
-          <TextFilter
-            defaultValue={filter}
-            label="by subject"
-            onChange={onFilterChange}
-          />
+          <TextFilter defaultValue={filter} label="by subject" onChange={onFilterChange} />
         </div>
       </div>
       <div className="co-m-pane__body">
@@ -496,16 +578,30 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({customData: {ki
           selectedCount={selectedCount}
           onSelectAll={onSelectAll}
         >
-          <CheckBox title="User" active={showUsers} number={users.length} toggle={toggleShowUsers} />
-          <CheckBox title="Group" active={showGroups} number={groups.length} toggle={toggleShowGroups} />
-          <CheckBox title="ServiceAccount" active={showServiceAccounts} number={serviceAccounts.length} toggle={toggleShowServiceAccounts} />
+          <CheckBox
+            title="User"
+            active={showUsers}
+            number={users.length}
+            toggle={toggleShowUsers}
+          />
+          <CheckBox
+            title="Group"
+            active={showGroups}
+            number={groups.length}
+            toggle={toggleShowGroups}
+          />
+          <CheckBox
+            title="ServiceAccount"
+            active={showServiceAccounts}
+            number={serviceAccounts.length}
+            toggle={toggleShowServiceAccounts}
+          />
         </CheckBoxControls>
         <p className="co-m-pane__explanation">
           The following subjects can {verb} {plural}
           {namespaced && namespace && <> in namespace {namespace}</>}
           {namespaced && !namespace && <> in all namespaces</>}
-          {!namespaced && <> at the cluster scope</>}
-          .
+          {!namespaced && <> at the cluster scope</>}.
         </p>
         <Table
           EmptyMsg={EmptyAccessReviewMsg}
@@ -521,32 +617,50 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({customData: {ki
   );
 };
 
-const APIResourcePage_ = ({match, kindObj, kindsInFlight, flags}: {match: any, kindObj: K8sKind, kindsInFlight: boolean, flags: {[key: string]: boolean}}) => {
+const APIResourcePage_ = ({
+  match,
+  kindObj,
+  kindsInFlight,
+  flags,
+}: {
+  match: any;
+  kindObj: K8sKind;
+  kindsInFlight: boolean;
+  flags: FlagsObject;
+}) => {
   if (!kindObj) {
-    return kindsInFlight
-      ? <LoadingBox />
-      : <div className="co-m-pane__body">
+    return kindsInFlight ? (
+      <LoadingBox />
+    ) : (
+      <div className="co-m-pane__body">
         <h1 className="co-m-pane__heading co-m-pane__heading--center">404: Not Found</h1>
-      </div>;
+      </div>
+    );
   }
 
-  const breadcrumbs = [{
-    name: 'Explore',
-    path: '/api-explorer',
-  }, {
-    name: 'Resource Details',
-    path: match.url,
-  }];
+  const breadcrumbs = [
+    {
+      name: 'Explore',
+      path: '/api-explorer',
+    },
+    {
+      name: 'Resource Details',
+      path: match.url,
+    },
+  ];
 
-  const pages = [{
-    href: '',
-    name: 'Overview',
-    component: APIResourceOverview,
-  }, {
-    href: 'schema',
-    name: 'Schema',
-    component: APIResourceSchema,
-  }];
+  const pages = [
+    {
+      href: '',
+      name: 'Overview',
+      component: APIResourceOverview,
+    },
+    {
+      href: 'schema',
+      name: 'Schema',
+      component: APIResourceSchema,
+    },
+  ];
 
   if (_.isEmpty(kindObj.verbs) || kindObj.verbs.includes('list')) {
     pages.push({
@@ -566,17 +680,21 @@ const APIResourcePage_ = ({match, kindObj, kindsInFlight, flags}: {match: any, k
 
   const namespace = kindObj.namespaced ? match.params.ns : null;
 
-  return <>
-    <ScrollToTopOnMount />
-    <Helmet>
-      <title>{kindObj.label}</title>
-    </Helmet>
-    <div className="co-m-nav-title co-m-nav-title--detail co-m-nav-title--breadcrumbs">
-      <BreadCrumbs breadcrumbs={breadcrumbs} />
-      <h1 className="co-m-pane__heading" data-test-id="api-explorer-resource-title">{kindObj.label}</h1>
-    </div>
-    <HorizontalNav pages={pages} match={match} customData={{kindObj, namespace}} noStatusBox />
-  </>;
+  return (
+    <>
+      <ScrollToTopOnMount />
+      <Helmet>
+        <title>{kindObj.label}</title>
+      </Helmet>
+      <div className="co-m-nav-title co-m-nav-title--detail co-m-nav-title--breadcrumbs">
+        <BreadCrumbs breadcrumbs={breadcrumbs} />
+        <h1 className="co-m-pane__heading" data-test-id="api-explorer-resource-title">
+          {kindObj.label}
+        </h1>
+      </div>
+      <HorizontalNav pages={pages} match={match} customData={{ kindObj, namespace }} noStatusBox />
+    </>
+  );
 };
 export const APIResourcePage = connectToModel(connectToFlags(FLAGS.OPENSHIFT)(APIResourcePage_));
 
