@@ -21,7 +21,12 @@ import {
   SectionHeading,
   WebhookTriggers,
 } from './utils';
-import { BuildsPage, BuildEnvironmentComponent, BuildStrategyType } from './build';
+import {
+  BuildsPage,
+  BuildEnvironmentComponent,
+  BuildStrategyType,
+  PipelineBuildStrategyAlert,
+} from './build';
 import { fromNow } from './utils/datetime';
 import { ResourceEventStream } from './events';
 import { BuildConfigModel } from '../models';
@@ -30,12 +35,15 @@ const BuildConfigsReference: K8sResourceKindReference = 'BuildConfig';
 
 const startBuildAction: KebabAction = (kind, buildConfig) => ({
   label: 'Start Build',
-  callback: () => startBuild(buildConfig).then(build => {
-    history.push(resourceObjPath(build, referenceFor(build)));
-  }).catch(err => {
-    const error = err.message;
-    errorModal({error});
-  }),
+  callback: () =>
+    startBuild(buildConfig)
+      .then((build) => {
+        history.push(resourceObjPath(build, referenceFor(build)));
+      })
+      .catch((err) => {
+        const error = err.message;
+        errorModal({ error });
+      }),
   accessReview: {
     group: kind.apiGroup,
     resource: kind.plural,
@@ -52,23 +60,36 @@ const menuActions = [
   ...Kebab.factory.common,
 ];
 
-export const BuildConfigsDetails: React.SFC<BuildConfigsDetailsProps> = ({obj: buildConfig}) => <React.Fragment>
-  <div className="co-m-pane__body">
-    <SectionHeading text="Build Config Overview" />
-    <div className="row">
-      <div className="col-sm-6">
-        <ResourceSummary resource={buildConfig} />
-      </div>
-      <div className="col-sm-6">
-        <BuildStrategy resource={buildConfig} />
-      </div>
-    </div>
-  </div>
-  <WebhookTriggers resource={buildConfig} />
-  <BuildHooks resource={buildConfig} />
-</React.Fragment>;
+export const BuildConfigsDetails: React.SFC<BuildConfigsDetailsProps> = ({ obj: buildConfig }) => {
+  const hasPipeline = buildConfig.spec.strategy.type === BuildStrategyType.JenkinsPipeline;
 
-const BuildsTabPage = ({obj: buildConfig}) => <BuildsPage namespace={buildConfig.metadata.namespace} showTitle={false} selector={{'openshift.io/build-config.name': buildConfig.metadata.name}} />;
+  return (
+    <>
+      <div className="co-m-pane__body">
+        {hasPipeline && <PipelineBuildStrategyAlert obj={buildConfig} />}
+        <SectionHeading text="Build Config Overview" />
+        <div className="row">
+          <div className="col-sm-6">
+            <ResourceSummary resource={buildConfig} />
+          </div>
+          <div className="col-sm-6">
+            <BuildStrategy resource={buildConfig} />
+          </div>
+        </div>
+      </div>
+      <WebhookTriggers resource={buildConfig} />
+      <BuildHooks resource={buildConfig} />
+    </>
+  );
+};
+
+const BuildsTabPage = ({ obj: buildConfig }) => (
+  <BuildsPage
+    namespace={buildConfig.metadata.namespace}
+    showTitle={false}
+    selector={{ 'openshift.io/build-config.name': buildConfig.metadata.name }}
+  />
+);
 
 const pages = [
   navFactory.details(BuildConfigsDetails),
@@ -78,12 +99,9 @@ const pages = [
   navFactory.events(ResourceEventStream),
 ];
 
-export const BuildConfigsDetailsPage: React.SFC<BuildConfigsDetailsPageProps> = props =>
-  <DetailsPage
-    {...props}
-    kind={BuildConfigsReference}
-    menuActions={menuActions}
-    pages={pages} />;
+export const BuildConfigsDetailsPage: React.SFC<BuildConfigsDetailsPageProps> = (props) => (
+  <DetailsPage {...props} kind={BuildConfigsReference} menuActions={menuActions} pages={pages} />
+);
 BuildConfigsDetailsPage.displayName = 'BuildConfigsDetailsPage';
 
 const tableColumnClasses = [
@@ -97,33 +115,47 @@ const tableColumnClasses = [
 const BuildConfigsTableHeader = () => {
   return [
     {
-      title: 'Name', sortField: 'metadata.name', transforms: [sortable],
+      title: 'Name',
+      sortField: 'metadata.name',
+      transforms: [sortable],
       props: { className: tableColumnClasses[0] },
     },
     {
-      title: 'Namespace', sortField: 'metadata.namespace', transforms: [sortable],
+      title: 'Namespace',
+      sortField: 'metadata.namespace',
+      transforms: [sortable],
       props: { className: tableColumnClasses[1] },
     },
     {
-      title: 'Labels', sortField: 'metadata.labels', transforms: [sortable],
+      title: 'Labels',
+      sortField: 'metadata.labels',
+      transforms: [sortable],
       props: { className: tableColumnClasses[2] },
     },
     {
-      title: 'Created', sortField: 'metadata.creationTimestamp', transforms: [sortable],
+      title: 'Created',
+      sortField: 'metadata.creationTimestamp',
+      transforms: [sortable],
       props: { className: tableColumnClasses[3] },
     },
     {
-      title: '', props: { className: tableColumnClasses[4] },
+      title: '',
+      props: { className: tableColumnClasses[4] },
     },
   ];
 };
 BuildConfigsTableHeader.displayName = 'BuildConfigsTableHeader';
 
-const BuildConfigsTableRow: React.FC<BuildConfigsTableRowProps> = ({obj, index, key, style}) => {
+const BuildConfigsTableRow: React.FC<BuildConfigsTableRowProps> = ({ obj, index, key, style }) => {
   return (
     <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
       <TableData className={tableColumnClasses[0]}>
-        <ResourceLink kind={BuildConfigsReference} name={obj.metadata.name} namespace={obj.metadata.namespace} title={obj.metadata.name} />
+        <ResourceLink
+          kind={BuildConfigsReference}
+          name={obj.metadata.name}
+          namespace={obj.metadata.namespace}
+          title={obj.metadata.name}
+        />
       </TableData>
       <TableData className={classNames(tableColumnClasses[1], 'co-break-word')}>
         <ResourceLink kind="Namespace" name={obj.metadata.namespace} />
@@ -132,7 +164,7 @@ const BuildConfigsTableRow: React.FC<BuildConfigsTableRowProps> = ({obj, index,
         <LabelList kind={BuildConfigsReference} labels={obj.metadata.labels} />
       </TableData>
       <TableData className={tableColumnClasses[3]}>
-        { fromNow(obj.metadata.creationTimestamp) }
+        {fromNow(obj.metadata.creationTimestamp)}
       </TableData>
       <TableData className={tableColumnClasses[4]}>
         <ResourceKebab actions={menuActions} kind={BuildConfigsReference} resource={obj} />
@@ -148,24 +180,40 @@ type BuildConfigsTableRowProps = {
   style: object;
 };
 
-const buildStrategy = (buildConfig: K8sResourceKind): BuildStrategyType => buildConfig.spec.strategy.type;
+const buildStrategy = (buildConfig: K8sResourceKind): BuildStrategyType =>
+  buildConfig.spec.strategy.type;
 
-const allStrategies = [BuildStrategyType.Docker, BuildStrategyType.JenkinsPipeline, BuildStrategyType.Source, BuildStrategyType.Custom];
-const filters = [{
-  type: 'build-strategy',
-  selected: allStrategies,
-  reducer: buildStrategy,
-  items: _.map(allStrategies, strategy => ({
-    id: strategy,
-    title: strategy,
-  })),
-}];
+const allStrategies = [
+  BuildStrategyType.Docker,
+  BuildStrategyType.JenkinsPipeline,
+  BuildStrategyType.Source,
+  BuildStrategyType.Custom,
+];
+const filters = [
+  {
+    type: 'build-strategy',
+    selected: allStrategies,
+    reducer: buildStrategy,
+    items: _.map(allStrategies, (strategy) => ({
+      id: strategy,
+      title: strategy,
+    })),
+  },
+];
 
-export const BuildConfigsList: React.SFC = props => <Table {...props} aria-label="Build Configs" Header={BuildConfigsTableHeader} Row={BuildConfigsTableRow} virtualize />;
+export const BuildConfigsList: React.SFC = (props) => (
+  <Table
+    {...props}
+    aria-label="Build Configs"
+    Header={BuildConfigsTableHeader}
+    Row={BuildConfigsTableRow}
+    virtualize
+  />
+);
 
 BuildConfigsList.displayName = 'BuildConfigsList';
 
-export const BuildConfigsPage: React.SFC<BuildConfigsPageProps> = props =>
+export const BuildConfigsPage: React.SFC<BuildConfigsPageProps> = (props) => (
   <ListPage
     {...props}
     title="Build Configs"
@@ -173,7 +221,9 @@ export const BuildConfigsPage: React.SFC<BuildConfigsPageProps> = props =>
     ListComponent={BuildConfigsList}
     canCreate={true}
     filterLabel={props.filterLabel}
-    rowFilters={filters} />;
+    rowFilters={filters}
+  />
+);
 BuildConfigsPage.displayName = 'BuildConfigsListPage';
 
 export type BuildConfigsDetailsProps = {
