@@ -10,6 +10,7 @@ import * as angularjsImg from '../../imgs/logos/angularjs.svg';
 import * as ansibleImg from '../../imgs/logos/ansible.svg';
 import * as apacheImg from '../../imgs/logos/apache.svg';
 import * as beakerImg from '../../imgs/logos/beaker.svg';
+import * as camelImg from '../../imgs/logos/camel.svg';
 import * as capedwarfImg from '../../imgs/logos/capedwarf.svg';
 import * as catalogImg from '../../imgs/logos/catalog-icon.svg';
 import * as cassandraImg from '../../imgs/logos/cassandra.svg';
@@ -97,6 +98,7 @@ const logos = new Map()
   .set('icon-ansible', ansibleImg)
   .set('icon-apache', apacheImg)
   .set('icon-beaker', beakerImg)
+  .set('icon-camel', camelImg)
   .set('icon-capedwarf', capedwarfImg)
   .set('icon-catalog', catalogImg)
   .set('icon-cassandra', cassandraImg)
@@ -189,7 +191,11 @@ export const getImageForIconClass = (iconClass: string): string => {
 };
 
 export const getServiceClassIcon = (serviceClass: K8sResourceKind): string => {
-  return _.get(serviceClass, ['spec', 'externalMetadata', 'console.openshift.io/iconClass'], logos.get('icon-catalog'));
+  return _.get(
+    serviceClass,
+    ['spec', 'externalMetadata', 'console.openshift.io/iconClass'],
+    logos.get('icon-catalog'),
+  );
 };
 
 export const getServiceClassImage = (serviceClass: K8sResourceKind): string => {
@@ -206,14 +212,33 @@ export const getTemplateIcon = (template: TemplateKind): string => {
   return _.get(template, 'metadata.annotations.iconClass');
 };
 
-export const ClusterServiceClassIcon: React.FC<ClusterServiceClassIconProps> = ({serviceClass, iconSize}) => {
+export const ClusterServiceClassIcon: React.FC<ClusterServiceClassIconProps> = ({
+  serviceClass,
+  iconSize,
+}) => {
   const iconClass = getServiceClassIcon(serviceClass);
   const imageUrl = getServiceClassImage(serviceClass);
-  return <span className="co-catalog-item-icon">
-    { imageUrl
-      ? <img className={classNames('co-catalog-item-icon__img', iconSize && `co-catalog-item-icon__img--${iconSize}`)} src={imageUrl} />
-      : <span className={classNames('co-catalog-item-icon__icon', iconSize && `co-catalog-item-icon__icon--${iconSize}`, normalizeIconClass(iconClass))} /> }
-  </span>;
+  return (
+    <span className="co-catalog-item-icon">
+      {imageUrl ? (
+        <img
+          className={classNames(
+            'co-catalog-item-icon__img',
+            iconSize && `co-catalog-item-icon__img--${iconSize}`,
+          )}
+          src={imageUrl}
+        />
+      ) : (
+        <span
+          className={classNames(
+            'co-catalog-item-icon__icon',
+            iconSize && `co-catalog-item-icon__icon--${iconSize}`,
+            normalizeIconClass(iconClass),
+          )}
+        />
+      )}
+    </span>
+  );
 };
 ClusterServiceClassIcon.displayName = 'ClusterServiceClassIcon';
 
@@ -222,14 +247,30 @@ export type ClusterServiceClassIconProps = {
   iconSize?: string;
 };
 
-export const ImageStreamIcon: React.FC<ImageStreamIconProps> = ({tag, iconSize}) => {
+export const ImageStreamIcon: React.FC<ImageStreamIconProps> = ({ tag, iconSize }) => {
   const iconClass = getImageStreamIcon(tag);
   const iconClassImg = getImageForIconClass(iconClass);
-  return <span className="co-catalog-item-icon">
-    { iconClassImg
-      ? <img className={classNames('co-catalog-item-icon__img', iconSize && `co-catalog-item-icon__img--${iconSize}`)} src={iconClassImg} />
-      : <span className={classNames('co-catalog-item-icon__icon', iconSize && `co-catalog-item-icon__icon--${iconSize}`, normalizeIconClass(iconClass))} /> }
-  </span>;
+  return (
+    <span className="co-catalog-item-icon">
+      {iconClassImg ? (
+        <img
+          className={classNames(
+            'co-catalog-item-icon__img',
+            iconSize && `co-catalog-item-icon__img--${iconSize}`,
+          )}
+          src={iconClassImg}
+        />
+      ) : (
+        <span
+          className={classNames(
+            'co-catalog-item-icon__icon',
+            iconSize && `co-catalog-item-icon__icon--${iconSize}`,
+            normalizeIconClass(iconClass),
+          )}
+        />
+      )}
+    </span>
+  );
 };
 
 export type ImageStreamIconProps = {
