@@ -2,14 +2,14 @@ import * as _ from 'lodash-es';
 import * as PropTypes from 'prop-types';
 import * as React from 'react';
 import { connect } from 'react-redux';
-
+import { getNodeRoles } from '@console/shared';
 import * as UIActions from '../../actions/ui';
 import { ingressValidHosts } from '../ingress';
 import { alertStateOrder, silenceStateOrder } from '../../reducers/monitoring';
 import { EmptyBox, StatusBox, WithScrollContainer } from '../utils';
 import {
   getJobTypeAndCompletions,
-  K8sResourceKind,
+  NodeKind,
   planExternalName,
   podPhase,
   podReadiness,
@@ -18,7 +18,6 @@ import {
   getClusterOperatorStatus,
   getClusterOperatorVersion,
   getTemplateInstanceStatus,
-  getNodeRoles,
 } from '../../module/k8s';
 
 import {
@@ -31,7 +30,7 @@ import {
   SortByDirection,
 } from '@patternfly/react-table';
 
-import { CellMeasurerCache, CellMeasurer} from 'react-virtualized';
+import { CellMeasurerCache, CellMeasurer } from 'react-virtualized';
 
 import {
   AutoSizer,
@@ -43,7 +42,7 @@ import { tableFilters } from './table-filters';
 
 const rowFiltersToFilterFuncs = (rowFilters) => {
   return (rowFilters || [])
-    .filter(f => f.type && _.isFunction(f.filter))
+    .filter((f) => f.type && _.isFunction(f.filter))
     .reduce((acc, f) => ({ ...acc, [f.type]: f.filter }), {});
 };
 
@@ -62,7 +61,7 @@ const getFilteredRows = (_filters, rowFilters, objects) => {
   _.each(_filters, (value, name) => {
     const filter = allTableFilters[name];
     if (_.isFunction(filter)) {
-      filteredObjects = _.filter(filteredObjects, o => filter(value, o));
+      filteredObjects = _.filter(filteredObjects, (o) => filter(value, o));
     }
   });
 
@@ -79,68 +78,79 @@ const filterPropType = (props, propName, componentName) => {
     if (key in allTableFilters || key === 'loadTest') {
       continue;
     }
-    return new Error(`Invalid prop '${propName}' in '${componentName}'. '${key}' is not a valid filter type!`);
+    return new Error(
+      `Invalid prop '${propName}' in '${componentName}'. '${key}' is not a valid filter type!`,
+    );
   }
 };
 
 const sorts = {
   alertStateOrder,
-  daemonsetNumScheduled: daemonset => _.toInteger(_.get(daemonset, 'status.currentNumberScheduled')),
-  dataSize: resource => _.size(_.get(resource, 'data')) + _.size(_.get(resource, 'binaryData')),
+  daemonsetNumScheduled: (daemonset) =>
+    _.toInteger(_.get(daemonset, 'status.currentNumberScheduled')),
+  dataSize: (resource) => _.size(_.get(resource, 'data')) + _.size(_.get(resource, 'binaryData')),
   ingressValidHosts,
   serviceCatalogStatus,
-  jobCompletions: job => getJobTypeAndCompletions(job).completions,
-  jobType: job => getJobTypeAndCompletions(job).type,
-  nodeReadiness: node => {
+  jobCompletions: (job) => getJobTypeAndCompletions(job).completions,
+  jobType: (job) => getJobTypeAndCompletions(job).type,
+  nodeReadiness: (node: NodeKind) => {
     let readiness = _.get(node, 'status.conditions');
-    readiness = _.find(readiness, {type: 'Ready'});
+    readiness = _.find(readiness, { type: 'Ready' });
     return _.get(readiness, 'status');
   },
-  numReplicas: resource => _.toInteger(_.get(resource, 'status.replicas')),
+  numReplicas: (resource) => _.toInteger(_.get(resource, 'status.replicas')),
   planExternalName,
   podPhase,
   podReadiness,
   serviceClassDisplayName,
   silenceStateOrder,
-  string: val => JSON.stringify(val),
-  number: val => _.toNumber(val),
+  string: (val) => JSON.stringify(val),
+  number: (val) => _.toNumber(val),
   getClusterOperatorStatus,
   getClusterOperatorVersion,
   getTemplateInstanceStatus,
-  nodeRoles: (node: K8sResourceKind): string => {
+  nodeRoles: (node: NodeKind): string => {
     const roles = getNodeRoles(node);
     return roles.sort().join(', ');
   },
 };
 
-const stateToProps = ({UI}, {
-  data = [],
-  defaultSortField = 'metadata.name',
-  defaultSortFunc = undefined,
-  defaultSortAsNumber = false,
-  filters = {},
-  loaded = false,
-  reduxID = null,
-  reduxIDs = null,
-  staticFilters = [{}],
-  rowFilters = []}) => {
+const stateToProps = (
+  { UI },
+  {
+    data = [],
+    defaultSortField = 'metadata.name',
+    defaultSortFunc = undefined,
+    defaultSortOrder = SortByDirection.asc,
+    defaultSortAsNumber = false,
+    filters = {},
+    loaded = false,
+    reduxID = null,
+    reduxIDs = null,
+    staticFilters = [{}],
+    rowFilters = [],
+  },
+) => {
   const allFilters = staticFilters ? Object.assign({}, filters, ...staticFilters) : filters;
   let newData = getFilteredRows(allFilters, rowFilters, data);
 
   const listId = reduxIDs ? reduxIDs.join(',') : reduxID;
   // Only default to 'metadata.name' if no `defaultSortFunc`
-  const currentSortField = UI.getIn(['listSorts', listId, 'field'], defaultSortFunc ? undefined : defaultSortField);
+  const currentSortField = UI.getIn(
+    ['listSorts', listId, 'field'],
+    defaultSortFunc ? undefined : defaultSortField,
+  );
   const currentSortFunc = UI.getIn(['listSorts', listId, 'func'], defaultSortFunc);
   const currentSortAsNumber = UI.getIn(['listSorts', listId, 'sortAsNumber'], defaultSortAsNumber);
-  const currentSortOrder = UI.getIn(['listSorts', listId, 'orderBy'], SortByDirection.asc);
+  const currentSortOrder = UI.getIn(['listSorts', listId, 'orderBy'], defaultSortOrder);
 
   if (loaded) {
     let sortBy: string | Function = 'metadata.name';
     if (currentSortField) {
       if (currentSortAsNumber) {
-        sortBy = resource => sorts.number(_.get(resource, currentSortField, ''));
+        sortBy = (resource) => sorts.number(_.get(resource, currentSortField, ''));
       } else {
-        sortBy = resource => sorts.string(_.get(resource, currentSortField, ''));
+        sortBy = (resource) => sorts.string(_.get(resource, currentSortField, ''));
       }
     } else if (currentSortFunc && sorts[currentSortFunc]) {
       // Sort resources by a function in the 'sorts' object
@@ -148,7 +158,11 @@ const stateToProps = ({UI}, {
     }
 
     // Always set the secondary sort criteria to ascending by name
-    newData = _.orderBy(newData, [sortBy, 'metadata.name'], [currentSortOrder, SortByDirection.asc]);
+    newData = _.orderBy(
+      newData,
+      [sortBy, 'metadata.name'],
+      [currentSortOrder, SortByDirection.asc],
+    );
   }
 
   return {
@@ -162,9 +176,25 @@ const stateToProps = ({UI}, {
 };
 
 // Common table row/columns helper SFCs for implementing accessible data grid
-export const TableRow: React.SFC<TableRowProps> = ({id, index, trKey, style, className, ...props}) => {
+export const TableRow: React.SFC<TableRowProps> = ({
+  id,
+  index,
+  trKey,
+  style,
+  className,
+  ...props
+}) => {
   return (
-    <tr {...props} data-id={id} data-index={index} data-test-rows="resource-row" data-key={trKey} style={style} className={className} role="row" />
+    <tr
+      {...props}
+      data-id={id}
+      data-index={index}
+      data-test-rows="resource-row"
+      data-key={trKey}
+      style={style}
+      className={className}
+      role="row"
+    />
   );
 };
 TableRow.displayName = 'TableRow';
@@ -174,20 +204,23 @@ export type TableRowProps = {
   trKey: string;
   style: object;
   className?: string;
-}
+};
 
-export const TableData: React.SFC<TableDataProps> = ({className, ...props}) => {
-  return (
-    <td {...props} className={className} role="gridcell" />
-  );
+export const TableData: React.SFC<TableDataProps> = ({ className, ...props }) => {
+  return <td {...props} className={className} role="gridcell" />;
 };
 TableData.displayName = 'TableData';
 export type TableDataProps = {
   id?: string;
   className?: string;
-}
+};
 
-const TableWrapper: React.SFC<TableWrapperProps> = ({virtualize, ariaLabel, ariaRowCount, ...props}) => {
+const TableWrapper: React.SFC<TableWrapperProps> = ({
+  virtualize,
+  ariaLabel,
+  ariaRowCount,
+  ...props
+}) => {
   return virtualize ? (
     <div {...props} role="grid" aria-label={ariaLabel} aria-rowcount={ariaRowCount} />
   ) : (
@@ -198,31 +231,54 @@ export type TableWrapperProps = {
   virtualize: boolean;
   ariaLabel: string;
   ariaRowCount: number | undefined;
-}
+};
 
 const VirtualBody: React.SFC<VirtualBodyProps> = (props) => {
-  const { customData, Row, height, isScrolling, onChildScroll, data, columns, scrollTop, width } = props;
+  const {
+    customData,
+    Row,
+    height,
+    isScrolling,
+    onChildScroll,
+    data,
+    columns,
+    scrollTop,
+    width,
+  } = props;
 
   const cellMeasurementCache = new CellMeasurerCache({
     fixedWidth: true,
     minHeight: 44,
-    keyMapper: rowIndex => _.get(props.data[rowIndex], 'metadata.uid', rowIndex),
+    keyMapper: (rowIndex) => _.get(props.data[rowIndex], 'metadata.uid', rowIndex),
   });
 
-  const rowRenderer = ({index, isScrolling: scrolling, isVisible, key, style, parent}) => {
-    const rowArgs = {obj: data[index], index, columns, isScrolling: scrolling, key, style, customData};
+  const rowRenderer = ({ index, isScrolling: scrolling, isVisible, key, style, parent }) => {
+    const rowArgs = {
+      obj: data[index],
+      index,
+      columns,
+      isScrolling: scrolling,
+      key,
+      style,
+      customData,
+    };
     const row = (Row as RowFunction)(rowArgs as RowFunctionArgs);
 
     // do not render non visible elements (this excludes overscan)
-    if (!isVisible){
+    if (!isVisible) {
       return null;
     }
-    return <CellMeasurer
-      cache={cellMeasurementCache}
-      columnIndex={0}
-      key={key}
-      parent={parent}
-      rowIndex={index}>{row}</CellMeasurer>;
+    return (
+      <CellMeasurer
+        cache={cellMeasurementCache}
+        columnIndex={0}
+        key={key}
+        parent={parent}
+        rowIndex={index}
+      >
+        {row}
+      </CellMeasurer>
+    );
   };
 
   return (
@@ -245,7 +301,15 @@ const VirtualBody: React.SFC<VirtualBodyProps> = (props) => {
   );
 };
 
-export type RowFunctionArgs = {obj: object, index: number, columns: [], isScrolling: boolean, key: string, style: object, customData?: any};
+export type RowFunctionArgs = {
+  obj: object;
+  index: number;
+  columns: [];
+  isScrolling: boolean;
+  key: string;
+  style: object;
+  customData?: any;
+};
 export type RowFunction = (args: RowFunctionArgs) => JSX.Element;
 
 export type VirtualBodyProps = {
@@ -259,26 +323,27 @@ export type VirtualBodyProps = {
   scrollTop: number;
   width: number;
   expand: boolean;
-}
+};
 
 export type TableProps = {
   customData?: any;
   data?: any[];
   defaultSortFunc?: string;
   defaultSortField?: string;
-  filters?: {[key: string]: any};
+  defaultSortOrder?: SortByDirection;
+  filters?: { [key: string]: any };
   Header: (...args) => any[];
   loadError?: string | Object;
   Row?: RowFunction | React.ComponentClass<any, any> | React.ComponentType<any>;
-  Rows?: (...args)=> any[];
+  Rows?: (...args) => any[];
   'aria-label': string;
   virtualize?: boolean;
-  AllItemsFilteredMsg?: React.ComponentType<{}>;
+  NoDataEmptyMsg?: React.ComponentType<{}>;
   EmptyMsg?: React.ComponentType<{}>;
   loaded?: boolean;
   reduxID?: string;
   reduxIDs?: string[];
-}
+};
 
 type TablePropsFromState = {};
 
@@ -286,20 +351,27 @@ type TablePropsFromDispatch = {};
 
 type TableOptionProps = {
   UI: any;
-}
+};
 
-export const Table = connect<TablePropsFromState,TablePropsFromDispatch,TableProps,TableOptionProps>(
+export const Table = connect<
+  TablePropsFromState,
+  TablePropsFromDispatch,
+  TableProps,
+  TableOptionProps
+>(
   stateToProps,
-  {sortList: UIActions.sortList},
+  { sortList: UIActions.sortList },
   null,
-  {areStatesEqual: ({UI: next}, {UI: prev}) => next.get('listSorts') === prev.get('listSorts')}
+  {
+    areStatesEqual: ({ UI: next }, { UI: prev }) => next.get('listSorts') === prev.get('listSorts'),
+  },
 )(
   class TableInner extends React.Component<TableInnerProps, TableInnerState> {
     static propTypes = {
       customData: PropTypes.any,
       data: PropTypes.array,
       unfilteredData: PropTypes.array,
-      AllItemsFilteredMsg: PropTypes.func,
+      NoDataEmptyMsg: PropTypes.func,
       EmptyMsg: PropTypes.func,
       expand: PropTypes.bool,
       fieldSelector: PropTypes.string,
@@ -329,11 +401,17 @@ export const Table = connect<TablePropsFromState,TablePropsFromDispatch,TablePro
     };
     _columnShift: number;
 
-    constructor(props){
+    constructor(props) {
       super(props);
-      const componentProps: any = _.pick(props, ['data', 'filters', 'selected', 'match', 'kindObj']);
+      const componentProps: any = _.pick(props, [
+        'data',
+        'filters',
+        'selected',
+        'match',
+        'kindObj',
+      ]);
       const columns = props.Header(componentProps);
-      const { currentSortField, currentSortFunc, currentSortOrder} = props;
+      const { currentSortField, currentSortFunc, currentSortOrder } = props;
 
       this._columnShift = props.onSelect ? 1 : 0; //shift indexes by 1 if select provided
       this._applySort = this._applySort.bind(this);
@@ -343,27 +421,33 @@ export const Table = connect<TablePropsFromState,TablePropsFromDispatch,TablePro
       let sortBy = {};
       if (currentSortField && currentSortOrder) {
         const columnIndex = _.findIndex(columns, { sortField: currentSortField });
-        if (columnIndex > -1){
+        if (columnIndex > -1) {
           sortBy = { index: columnIndex + this._columnShift, direction: currentSortOrder };
         }
       } else if (currentSortFunc && currentSortOrder) {
         const columnIndex = _.findIndex(columns, { sortFunc: currentSortFunc });
-        if (columnIndex > -1){
+        if (columnIndex > -1) {
           sortBy = { index: columnIndex + this._columnShift, direction: currentSortOrder };
         }
       }
       this.state = { columns, sortBy };
     }
 
-    componentDidMount(){
-      const {columns} = this.state;
+    componentDidMount() {
+      const { columns } = this.state;
       const sp = new URLSearchParams(window.location.search);
-      const columnIndex = _.findIndex(columns, {title: sp.get('sortBy')});
+      const columnIndex = _.findIndex(columns, { title: sp.get('sortBy') });
 
-      if (columnIndex > -1){
+      if (columnIndex > -1) {
         const sortOrder = sp.get('orderBy') || SortByDirection.asc;
         const column = columns[columnIndex];
-        this._applySort(column.sortField, column.sortFunc, column.sortAsNumber, sortOrder, column.title);
+        this._applySort(
+          column.sortField,
+          column.sortFunc,
+          column.sortAsNumber,
+          sortOrder,
+          column.title,
+        );
         this.setState({
           sortBy: {
             index: columnIndex + this._columnShift,
@@ -376,7 +460,7 @@ export const Table = connect<TablePropsFromState,TablePropsFromDispatch,TablePro
       window.addEventListener('resize', this._handleResize);
     }
 
-    componentWillUnmount(){
+    componentWillUnmount() {
       window.removeEventListener('resize', this._handleResize);
     }
 
@@ -384,16 +468,22 @@ export const Table = connect<TablePropsFromState,TablePropsFromDispatch,TablePro
       this.forceUpdate();
     }
 
-    _applySort(sortField, sortFunc, sortAsNumber, direction, columnTitle){
-      const {sortList, listId, currentSortFunc} = this.props;
+    _applySort(sortField, sortFunc, sortAsNumber, direction, columnTitle) {
+      const { sortList, listId, currentSortFunc } = this.props;
       const applySort = _.partial(sortList, listId);
       applySort(sortField, sortFunc || currentSortFunc, sortAsNumber, direction, columnTitle);
     }
 
-    _onSort(event, index, direction){
+    _onSort(event, index, direction) {
       event.preventDefault();
       const sortColumn = this.state.columns[index - this._columnShift];
-      this._applySort(sortColumn.sortField, sortColumn.sortFunc, sortColumn.sortAsNumber, direction, sortColumn.title);
+      this._applySort(
+        sortColumn.sortField,
+        sortColumn.sortFunc,
+        sortColumn.sortAsNumber,
+        direction,
+        sortColumn.title,
+      );
       this.setState({
         sortBy: {
           index,
@@ -403,16 +493,35 @@ export const Table = connect<TablePropsFromState,TablePropsFromDispatch,TablePro
     }
 
     render() {
-      const {scrollElement, Rows, Row, expand, label, mock, onSelect, selectedResourcesForKind, 'aria-label': ariaLabel, virtualize = true, customData, gridBreakPoint = TableGridBreakpoint.none} = this.props;
-      const {sortBy, columns} = this.state;
-      const componentProps: any = _.pick(this.props, ['data', 'filters', 'selected', 'match', 'kindObj']);
+      const {
+        scrollElement,
+        Rows,
+        Row,
+        expand,
+        label,
+        mock,
+        onSelect,
+        selectedResourcesForKind,
+        'aria-label': ariaLabel,
+        virtualize = true,
+        customData,
+        gridBreakPoint = TableGridBreakpoint.none,
+      } = this.props;
+      const { sortBy, columns } = this.state;
+      const componentProps: any = _.pick(this.props, [
+        'data',
+        'filters',
+        'selected',
+        'match',
+        'kindObj',
+      ]);
       const ariaRowCount = componentProps.data && componentProps.data.length;
       const scrollNode = typeof scrollElement === 'function' ? scrollElement() : scrollElement;
       const renderVirtualizedTable = (scrollContainer) => (
         <WindowScroller scrollElement={scrollContainer}>
-          {({height, isScrolling, registerChild, onChildScroll, scrollTop}) => (
+          {({ height, isScrolling, registerChild, onChildScroll, scrollTop }) => (
             <AutoSizer disableHeight>
-              {({width}) => (
+              {({ width }) => (
                 <div ref={registerChild}>
                   <VirtualBody
                     Row={Row}
@@ -432,11 +541,13 @@ export const Table = connect<TablePropsFromState,TablePropsFromDispatch,TablePro
           )}
         </WindowScroller>
       );
-      const children = mock ? <EmptyBox label={label} /> : (
+      const children = mock ? (
+        <EmptyBox label={label} />
+      ) : (
         <TableWrapper virtualize={virtualize} ariaLabel={ariaLabel} ariaRowCount={ariaRowCount}>
           <PfTable
             cells={columns}
-            rows={virtualize ? (customData || []) : Rows({componentProps, selectedResourcesForKind, customData})}
+            rows={virtualize ? [] : Rows({ componentProps, selectedResourcesForKind, customData })}
             gridBreakPoint={gridBreakPoint}
             onSort={this._onSort}
             onSelect={onSelect}
@@ -446,9 +557,7 @@ export const Table = connect<TablePropsFromState,TablePropsFromDispatch,TablePro
             aria-label={virtualize ? null : ariaLabel}
           >
             <TableHeader />
-            {!virtualize && (
-              <TableBody />
-            )}
+            {!virtualize && <TableBody />}
           </PfTable>
           {virtualize &&
             (scrollNode ? (
@@ -458,14 +567,20 @@ export const Table = connect<TablePropsFromState,TablePropsFromDispatch,TablePro
             ))}
         </TableWrapper>
       );
-      return <div className="co-m-table-grid co-m-table-grid--bordered">
-        { mock
-          ? children
-          : <StatusBox skeleton={<div className="loading-skeleton--table" />} {...this.props}>{children}</StatusBox> }
-      </div>;
+      return (
+        <div className="co-m-table-grid co-m-table-grid--bordered">
+          {mock ? (
+            children
+          ) : (
+            <StatusBox skeleton={<div className="loading-skeleton--table" />} {...this.props}>
+              {children}
+            </StatusBox>
+          )}
+        </div>
+      );
     }
-  });
-
+  },
+);
 
 export type TableInnerProps = {
   'aria-label': string;
@@ -477,11 +592,11 @@ export type TableInnerProps = {
   defaultSortField?: string;
   defaultSortFunc?: string;
   unfilteredData?: any[];
-  AllItemsFilteredMsg?: React.ComponentType<{}>;
+  NoDataEmptyMsg?: React.ComponentType<{}>;
   EmptyMsg?: React.ComponentType<{}>;
   expand?: boolean;
   fieldSelector?: string;
-  filters?: {[name: string]: any};
+  filters?: { [name: string]: any };
   Header: (...args) => any[];
   label?: string;
   listId?: string;
@@ -492,11 +607,24 @@ export type TableInnerProps = {
   reduxID?: string;
   reduxIDs?: string[];
   Row?: RowFunction | React.ComponentClass<any, any> | React.ComponentType<any>;
-  Rows?: (...args)=> any[];
+  Rows?: (...args) => any[];
   selector?: Object;
-  sortList?: (listId: string, field: string, func: any, sortAsNumber: boolean, orderBy: string, column: string) => any;
+  sortList?: (
+    listId: string,
+    field: string,
+    func: any,
+    sortAsNumber: boolean,
+    orderBy: string,
+    column: string,
+  ) => any;
   selectedResourcesForKind?: string[];
-  onSelect?: (event: React.MouseEvent, isSelected: boolean, rowIndex: number, rowData: IRowData, extraData: IExtraData) => void;
+  onSelect?: (
+    event: React.MouseEvent,
+    isSelected: boolean,
+    rowIndex: number,
+    rowData: IRowData,
+    extraData: IExtraData,
+  ) => void;
   staticFilters?: any[];
   rowFilters?: any[];
   virtualize?: boolean;
