@@ -22,12 +22,12 @@ const PerspectiveNav: React.FC<StateProps> = ({ perspective }) => {
   const renderedSections: string[] = [];
 
   return (
-    <React.Fragment>
+    <>
       {_.compact(
         plugins.registry
           .getNavItems()
-          .filter(item => item.properties.perspective === perspective)
-          .map(item => {
+          .filter((item) => item.properties.perspective === perspective)
+          .map((item) => {
             const { section } = item.properties;
             if (section) {
               if (renderedSections.includes(section)) {
@@ -37,9 +37,9 @@ const PerspectiveNav: React.FC<StateProps> = ({ perspective }) => {
               return <NavSection title={section} key={section} />;
             }
             return createLink(item, true);
-          })
+          }),
       )}
-    </React.Fragment>
+    </>
   );
 };
 
