@@ -1,9 +1,9 @@
 import { JSONSchema6 } from 'json-schema';
+import { BadgeType } from '@console/shared';
 import { EventInvolvedObject } from './event';
 
 export * from './job';
 export * from './k8s';
-export * from './node';
 export * from './pods';
 export * from './resource';
 export * from './service-catalog';
@@ -36,15 +36,28 @@ export type ObjectReference = {
 };
 
 export type ObjectMetadata = {
-  name?: string;
-  generateName?: string;
-  uid?: string;
-  annotations?: {[key: string]: string},
-  namespace?: string,
-  labels?: {[key: string]: string},
-  ownerReferences?: OwnerReference[],
+  annotations?: { [key: string]: string };
+  clusterName?: string;
+  creationTimestamp?: string;
+  deletionGracePeriodSeconds?: number;
   deletionTimestamp?: string;
-  [key: string]: any,
+  finalizers?: string[];
+  generateName?: string;
+  generation?: number;
+  labels?: { [key: string]: string };
+  managedFields?: any[];
+  name?: string;
+  namespace?: string;
+  ownerReferences?: OwnerReference[];
+  resourceVersion?: string;
+  selfLink?: string;
+  uid?: string;
+};
+
+export type PartialObjectMetadata = {
+  apiVersion: string;
+  kind: string;
+  metadata: ObjectMetadata;
 };
 
 export enum K8sResourceConditionStatus {
@@ -61,10 +74,16 @@ export type K8sResourceCondition<T> = {
   message: string;
 };
 
-export type MatchExpression = {key: string, operator: 'Exists' | 'DoesNotExist'} | {key: string, operator: 'In' | 'NotIn' | 'Equals' | 'NotEquals', values: string[]};
+export type MatchExpression =
+  | { key: string; operator: 'Exists' | 'DoesNotExist' }
+  | { key: string; operator: 'In' | 'NotIn' | 'Equals' | 'NotEquals'; values: string[] };
+
+export type MatchLabels = {
+  [key: string]: string;
+};
 
 export type Selector = {
-  matchLabels?: {[key: string]: string};
+  matchLabels?: MatchLabels;
   matchExpressions?: MatchExpression[];
 };
 
@@ -79,31 +98,41 @@ export type Taint = {
 export type TolerationOperator = 'Exists' | 'Equal';
 
 export type Toleration = {
+  effect: TaintEffect;
   key?: string;
   operator: TolerationOperator;
+  tolerationSeconds?: number;
   value?: string;
-  effect: TaintEffect;
 };
 
+// Properties common to (almost) all Kubernetes resources.
+export type K8sResourceCommon = {
+  apiVersion: string;
+  kind: string;
+  metadata: ObjectMetadata;
+};
+
+// Generic, unknown kind. Avoid when possible since it allows any key in spec
+// or status, weakening type checking.
 export type K8sResourceKind = {
   apiVersion?: string;
   kind?: string;
   metadata?: ObjectMetadata;
   spec?: {
-    selector?: Selector;
-    [key: string]: any
+    selector?: Selector | MatchLabels;
+    [key: string]: any;
   };
-  status?: {[key: string]: any};
-  type?: {[key: string]: any};
-  data?: {[key: string]: any};
+  status?: { [key: string]: any };
+  type?: { [key: string]: any };
+  data?: { [key: string]: any };
 };
 
 export type VolumeMount = {
-  name: string;
-  readOnly: boolean;
   mountPath: string;
-  subPath?: string;
   mountPropagation?: 'None' | 'HostToContainer' | 'Bidirectional';
+  name: string;
+  readOnly?: boolean;
+  subPath?: string;
   subPathExpr?: string;
 };
 
@@ -252,7 +281,8 @@ export type PodSpec = {
   [key: string]: any;
 };
 
-type PodPhase = 'Pending' | 'Running' | 'Succeeded' | 'Failed' | 'Unknown';
+// https://github.com/kubernetes/api/blob/release-1.16/core/v1/types.go#L2411-L2432
+export type PodPhase = 'Pending' | 'Running' | 'Succeeded' | 'Failed' | 'Unknown';
 
 type ContainerStateValue = {
   reason?: string;
@@ -283,7 +313,7 @@ export type PodCondition = {
   message?: string;
   lastTransitionTime?: string;
   lastProbeTime?: string;
-}
+};
 
 export type PodStatus = {
   phase: PodPhase;
@@ -297,31 +327,121 @@ export type PodStatus = {
 };
 
 export type PodTemplate = {
+  metadata: ObjectMetadata;
   spec: PodSpec;
 };
 
 export type PodKind = {
   status: PodStatus;
-} & PodTemplate & K8sResourceKind;
+} & K8sResourceCommon &
+  PodTemplate;
+
+export type DeploymentKind = {
+  spec: {
+    minReadySeconds?: number;
+    paused?: boolean;
+    progressDeadlineSeconds?: number;
+    replicas?: number;
+    revisionHistoryLimit?: number;
+    selector: Selector;
+    strategy?: {
+      rollingUpdate?: {
+        maxSurge: number | string;
+        maxUnavailable: number | string;
+      };
+      type?: string;
+    };
+    template: PodTemplate;
+  };
+  status?: {
+    availableReplicas?: number;
+    collisionCount?: number;
+    conditions?: any[];
+    observedGeneration?: number;
+    readyReplicas?: number;
+    replicas?: number;
+    unavailableReplicas?: number;
+    updatedReplicas?: number;
+  };
+} & K8sResourceCommon;
 
 export type StorageClassResourceKind = {
   provisioner: string;
   reclaimPolicy: string;
-} & K8sResourceKind;
+} & K8sResourceCommon;
 
 export type NodeKind = {
-  spec?: {
+  spec: {
     taints?: Taint[];
     unschedulable?: boolean;
   };
-} & K8sResourceKind;
+  status?: {
+    conditions?: any;
+    images?: {
+      names: string[];
+      sizeBytes?: number;
+    }[];
+    phase?: string;
+  };
+} & K8sResourceCommon;
 
 export type ConfigMapKind = {
+  data: { [key: string]: string };
+  binaryData: { [key: string]: string };
+} & K8sResourceCommon;
+
+export type JobTemplate = {
+  metadata: ObjectMetadata;
+  spec: {
+    activeDeadlineSeconds?: number;
+    backoffLimit?: number;
+    completions?: number;
+    manualSelector?: boolean;
+    parallelism?: boolean;
+    selector?: Selector;
+    template: PodTemplate;
+    ttlSecondsAfterFinished?: number;
+  };
+};
+
+export type JobKind = {
+  apiVersion: string;
+  kind: string;
+  status: {
+    active?: number;
+    completionTime?: string;
+    conditions?: any;
+    failed?: number;
+    startTime?: string;
+    succeeded?: number;
+  };
+} & JobTemplate;
+
+export type CronJobKind = {
   apiVersion: string;
   kind: string;
   metadata: ObjectMetadata;
-  data: {[key: string]: string};
-  binaryData: {[key: string]: string};
+  spec: {
+    concurrencyPolicy?: string;
+    failedJobsHistoryLimit?: number;
+    jobTemplate: JobTemplate;
+    schedule: string;
+    startingDeadlineSeconds?: number;
+    successfulJobsHistoryLimit?: number;
+    suspend?: boolean;
+  };
+  status: {
+    active?: {
+      apiVersion?: string;
+      fieldPath?: string;
+      kind?: string;
+      name?: string;
+      namespace?: string;
+      resourceVersion?: string;
+      uid?: string;
+    }[];
+    lastScheduleTime?: string;
+  };
 };
 
 export type CustomResourceDefinitionKind = {
@@ -339,9 +459,53 @@ export type CustomResourceDefinitionKind = {
     validation?: {
       // NOTE: Actually a subset of JSONSchema, but using this type for convenience
       openAPIV3Schema: JSONSchema6;
-    }
-  }
-} & K8sResourceKind;
+    };
+  };
+  status?: {
+    conditions?: any[];
+  };
+} & K8sResourceCommon;
+
+export type RouteTarget = {
+  kind: 'Service';
+  name: string;
+  weight: number;
+};
+
+export type RouteTLS = {
+  caCertificate?: string;
+  certificate?: string;
+  destinationCACertificate?: string;
+  insecureEdgeTerminationPolicy?: string;
+  key?: string;
+  termination: string;
+};
+
+export type RouteIngress = {
+  conditions: any[];
+  host?: string;
+  routerCanonicalHostname?: string;
+  routerName?: string;
+  wildcardPolicy?: string;
+};
+
+export type RouteKind = {
+  spec: {
+    alternateBackends?: RouteTarget[];
+    host?: string;
+    path?: string;
+    port?: {
+      targetPort: number | string;
+    };
+    subdomain?: string;
+    tls?: RouteTLS;
+    to: RouteTarget;
+    wildcardPolicy?: string;
+  };
+  status?: {
+    ingress: RouteIngress[];
+  };
+} & K8sResourceCommon;
 
 export type TemplateParameter = {
   name: string;
@@ -357,7 +521,7 @@ export type TemplateKind = {
   objects: any[];
   parameters: TemplateParameter[];
   labels?: any[];
-} & K8sResourceKind;
+} & K8sResourceCommon;
 
 type TemplateInstanceObject = {
   ref: ObjectReference;
@@ -380,7 +544,7 @@ export type TemplateInstanceKind = {
     conditions: any[];
     objects: TemplateInstanceObject[];
   };
-} & K8sResourceKind;
+} & K8sResourceCommon;
 
 export type MachineSpec = {
   providerSpec: {
@@ -395,6 +559,7 @@ export type MachineSpec = {
 export type MachineKind = {
   spec: MachineSpec;
   status?: {
+    phase?: string;
     addresses: {
       address?: string;
       type: string;
@@ -411,11 +576,12 @@ export type MachineKind = {
       [key: string]: any;
     };
   };
-} & K8sResourceKind;
+} & K8sResourceCommon;
 
 export type MachineSetKind = {
   spec: {
     replicas: number;
+    selector: any;
     template: {
       spec: MachineSpec;
     };
@@ -426,7 +592,7 @@ export type MachineSetKind = {
     readyReplicas: number;
     replicas: number;
   };
-} & K8sResourceKind;
+} & K8sResourceCommon;
 
 export type Patch = {
   op: string;
@@ -434,13 +600,15 @@ export type Patch = {
   value?: any;
 };
 
-export type RollingUpdate = {maxUnavailable?: number | string, maxSurge?: number | string};
-export type DeploymentUpdateStrategy = {
-  type: 'Recreate';
-} | {
-  type: 'RollingUpdate';
-  rollingUpdate: RollingUpdate;
-};
+export type RollingUpdate = { maxUnavailable?: number | string; maxSurge?: number | string };
+export type DeploymentUpdateStrategy =
+  | {
+      type: 'Recreate';
+    }
+  | {
+      type: 'RollingUpdate';
+      rollingUpdate: RollingUpdate;
+    };
 
 export type MachineDeploymentKind = {
   spec: {
@@ -460,14 +628,14 @@ export type MachineDeploymentKind = {
     readyReplicas: number;
     replicas: number;
   };
-} & K8sResourceKind;
+} & K8sResourceCommon;
 
 export type MachineConfigKind = {
   spec: {
     osImageURL: string;
     config: any;
   };
-} & K8sResourceKind;
+} & K8sResourceCommon;
 
 export enum MachineConfigPoolConditionType {
   Updated = 'Updated',
@@ -479,7 +647,7 @@ export type MachineConfigPoolCondition = K8sResourceCondition<MachineConfigPoolC
 
 export type MachineConfigPoolStatus = {
   observedGeneration?: number;
-  configuration:{
+  configuration: {
     name: string;
     source: ObjectReference[];
   };
@@ -542,7 +710,7 @@ type ClusterVersionSpec = {
 export type ClusterVersionKind = {
   spec: ClusterVersionSpec;
   status: ClusterVersionStatus;
-} & K8sResourceKind;
+} & K8sResourceCommon;
 
 export type OperandVersion = {
   name: string;
@@ -563,11 +731,20 @@ export type ClusterOperator = {
     versions?: OperandVersion[];
     relatedObjects?: ClusterOperatorObjectReference[];
   };
-} & K8sResourceKind;
+} & K8sResourceCommon;
 
 export type MappingMethodType = 'claim' | 'lookup' | 'add';
 
-type IdentityProviderType = 'BasicAuth' | 'GitHub' | 'GitLab' | 'Google' | 'HTPasswd' | 'Keystone' | 'LDAP' | 'OpenID' | 'RequestHeader';
+type IdentityProviderType =
+  | 'BasicAuth'
+  | 'GitHub'
+  | 'GitLab'
+  | 'Google'
+  | 'HTPasswd'
+  | 'Keystone'
+  | 'LDAP'
+  | 'OpenID'
+  | 'RequestHeader';
 
 type IdentityProviderConfig = {
   [key: string]: any;
@@ -600,20 +777,31 @@ export type OAuthKind = {
       error: string;
     };
   };
-} & K8sResourceKind;
+} & K8sResourceCommon;
 
-export type K8sVerb = 'create' | 'get' | 'list' | 'update' | 'patch' | 'delete' | 'deletecollection' | 'watch';
+export type K8sVerb =
+  | 'create'
+  | 'get'
+  | 'list'
+  | 'update'
+  | 'patch'
+  | 'delete'
+  | 'deletecollection'
+  | 'watch';
 
 export type AccessReviewResourceAttributes = {
-    group?: string;
-    resource?: string;
-    subresource?: string;
-    verb?: K8sVerb;
-    name?: string;
-    namespace?: string;
+  group?: string;
+  resource?: string;
+  subresource?: string;
+  verb?: K8sVerb;
+  name?: string;
+  namespace?: string;
 };
 
 export type SelfSubjectAccessReviewKind = {
+  apiVersion: string;
+  kind: string;
+  metadata?: ObjectMetadata;
   spec: {
     resourceAttributes?: AccessReviewResourceAttributes;
   };
@@ -623,21 +811,32 @@ export type SelfSubjectAccessReviewKind = {
     reason?: string;
     evaluationError?: string;
   };
-} & K8sResourceKind;
+};
 
 export type ResourceAccessReviewRequest = {
+  apiVersion: string;
+  kind: string;
   namespace?: string;
   resourceAPIVersion: string;
   resourceAPIGroup: string;
   resource: string;
   verb: K8sVerb;
-} & K8sResourceKind;
+};
 
 export type ResourceAccessReviewResponse = {
   namespace?: string;
   users: string[];
   groups: string[];
-} & K8sResourceKind;
+} & K8sResourceCommon;
+
+export type UserKind = {
+  fullName?: string;
+  identities: string[];
+} & K8sResourceCommon;
+
+export type GroupKind = {
+  users: string[];
+} & K8sResourceCommon;
 
 export type K8sKind = {
   abbr: string;
@@ -653,10 +852,17 @@ export type K8sKind = {
   apiGroup?: string;
   namespaced?: boolean;
   selector?: Selector;
-  labels?: {[key: string]: string};
-  annotations?: {[key: string]: string};
+  labels?: { [key: string]: string };
+  annotations?: { [key: string]: string };
   verbs?: K8sVerb[];
   shortNames?: string[];
+  badge?: BadgeType;
+  color?: string;
+
+  // Legacy option for supporing plural names in URL paths when `crd: true`.
+  // This should not be set for new models, but is needed to avoid breaking
+  // existing links as we transition to using the API group in URL paths.
+  legacyPluralURL?: boolean;
 };
 
 export type Cause = {
@@ -692,16 +898,23 @@ export type GroupVersionKind = string;
  */
 export type K8sResourceKindReference = GroupVersionKind | string;
 
-export type EventKind = K8sResourceKind & {
-  count: number;
-  type: string;
+export type EventKind = {
+  action?: string;
+  count?: number;
+  type?: string;
   involvedObject: EventInvolvedObject;
-  message: string;
-  lastTimestamp: string;
-  firstTimestamp: string;
-  reason: string;
+  message?: string;
+  eventTime?: string;
+  lastTimestamp?: string;
+  firstTimestamp?: string;
+  reason?: string;
   source: {
     component: string;
     host?: string;
-  }
-};
+  };
+  series?: {
+    count?: number;
+    lastObservedTime?: string;
+    state?: string;
+  };
+} & K8sResourceCommon;
